@@ -16,9 +16,12 @@
 #include "netrom.h"
 #include "trace.h"
 #include "pktdrvr.h"
+#ifdef APRSD
+#include "aprs.h"
+#endif
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: ax25.c,v 1.27 1997/09/07 00:31:16 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: ax25.c,v 1.28 2001/05/06 16:32:54 brian Exp $";
 #endif
 
 static int axsend (struct iface * iface, const char *dest, char *source,
@@ -482,6 +485,28 @@ int send2axui = 0;
 			free_p (nbp);
 		}
 	}
+
+#ifdef	APRSD
+	/*
+	 * I was hoping to use the MULTICAST feature to handle APRS stuff, but that
+	 * won't work if people are digipeating multicast type destination addresses
+	 * over the provincial nodes to get here. Argh, but this will work for now.
+	 *
+	 * Only go to APRS processing if this is a UI frame, with NO protocol.
+	 *
+	 * 12Apr2001, VE4KLM
+	 *
+	 */	
+		if ((bp->data[0] & ~PF) == UI && bp->data[1] == PID_NO_L3)
+		{
+			if (aprs_processing (&hdr, bp))
+			{
+				free_p (bp);
+				return;
+			}
+		}
+#endif
+
 	/* If there were digis in this packet and at least one has
 	 * been passed, then the last passed digi is the immediate source.
 	 * Otherwise it is the original source.
