@@ -9,7 +9,7 @@
 #include "trace.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: ax25dump.c,v 1.12 1997/08/19 01:19:22 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: ax25dump.c,v 1.13 2000/05/09 16:48:24 brian Exp $";
 #endif
 
 static const char *decode_the_type (int16 type);
@@ -30,20 +30,44 @@ int unsegmented;
 struct ax25 hdr;
 char *hp;
 
+#ifdef CTRACE
+	if (use_ctrace)
+		traceprintf (fp, Acyan);
+#endif
 	traceprintf (fp, "AX25: ");
 	/* Extract the address header */
 	if (ntohax25 (&hdr, bpp) < 0) {
 		/* Something wrong with the header */
+#ifdef CTRACE
+		if (use_ctrace)
+        		traceprintf (fp, " %sbad header!%s%s\n", Aalert, Acyan, Aboldoff);
+		else
+#endif
 		traceprintf (fp, " bad header!\n");
 		return;
 	}
+#ifdef CTRACE
+	if (use_ctrace) {
+		traceprintf (fp, "%s%s%s", Abold, pax25 (tmp, hdr.source), Aboldoff);
+		traceprintf (fp, "->%s%s%s", Abold, pax25 (tmp, hdr.dest), Aboldoff);
+	} else {
+#endif
 	traceprintf (fp, "%s", pax25 (tmp, hdr.source));
 	traceprintf (fp, "->%s", pax25 (tmp, hdr.dest));
+#ifdef CTRACE
+	}
+#endif
 	if (hdr.ndigis > 0) {
 		traceprintf (fp, " v");
 		for (hp = hdr.digis[0]; hp < &hdr.digis[hdr.ndigis][0];
 		     hp += AXALEN) {
 			/* Print digi string */
+#ifdef CTRACE
+			if (use_ctrace)
+				traceprintf (fp, " %s%s%s%s", Abold, pax25 (tmp, hp),
+				     (hp[ALEN] & REPEATED) ? "*" : "", Aboldoff);
+			else
+#endif
 			traceprintf (fp, " %s%s", pax25 (tmp, hp),
 				     (hp[ALEN] & REPEATED) ? "*" : "");
 		}
@@ -53,17 +77,37 @@ char *hp;
 
 	traceprintf (fp, " ");
 	type = ftype (control);
+#ifdef CTRACE
+	if (use_ctrace)
+		traceprintf (fp, "%s%s%s", Abold, decode_the_type (type), Aboldoff);
+	else
+#endif	
 	traceprintf (fp, "%s", decode_the_type (type));
 	/* Dump poll/final bit */
 	if (control & PF) {
 		switch (hdr.cmdrsp) {
 			case LAPB_COMMAND:
+#ifdef CTRACE
+				if (use_ctrace)
+					traceprintf (fp, "(%sP%s)", Abold, Aboldoff);
+				else
+#endif				
 				traceprintf (fp, "(P)");
 				break;
 			case LAPB_RESPONSE:
+#ifdef CTRACE
+				if (use_ctrace)
+					traceprintf (fp, "(%sF%s)", Abold, Aboldoff);
+				else
+#endif				
 				traceprintf (fp, "(F)");
 				break;
 			default:
+#ifdef CTRACE
+				if (use_ctrace)
+					traceprintf (fp, "(%sP/F%s)", Abold, Aboldoff);
+				else
+#endif				
 				traceprintf (fp, "(P/F)");
 				break;
 		}
@@ -91,10 +135,20 @@ char *hp;
 					traceprintf (fp, "\n");
 					break;	/* Already displayed */
 				case PID_ARP:
+#ifdef CTRACE
+					if (use_ctrace)
+						traceprintf (fp, " pid=%sARP%s (0x%x)\n", Abold, Aboldoff, pid);
+					else
+#endif
 					traceprintf (fp, " pid=ARP (0x%x)\n", pid);
 					arp_dump (fp, bpp);
 					break;
 				case PID_RARP:
+#ifdef CTRACE
+					if (use_ctrace)
+						traceprintf (fp, " pid=%sRARP%s (0x%x)\n", Abold, Aboldoff, pid);
+					else
+#endif					
 					traceprintf (fp, " pid=RARP (0x%x)\n", pid);
 					arp_dump (fp, bpp);
 					break;
@@ -106,6 +160,11 @@ char *hp;
 #endif
 					break;
 				case PID_IP:
+#ifdef CTRACE
+					if (use_ctrace)
+						traceprintf (fp, " pid=%sIP%s (0x%x)\n", Abold, Aboldoff, pid);
+					else
+#endif					
 					traceprintf (fp, " pid=IP (0x%x)\n", pid);
 					/* Don't verify checksums unless unsegmented */
 					ip_dump (fp, bpp, unsegmented);
