@@ -4,12 +4,15 @@
 
 #ifdef UNIX
 #include <netdb.h>
-#endif
+#include <netinet/in.h>
+#include "mbuf.h"
+#else
 #include "socket.h"
+#endif
 #include "bldsaddr.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: bldsaddr.c,v 1.11 1997/08/19 01:19:22 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: bldsaddr.c,v 1.12 2000/05/09 16:48:24 brian Exp $";
 #endif
 
 static union {
