@@ -34,7 +34,7 @@
 #include "color.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: bmutil.c,v 1.40 1997/08/19 01:19:22 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: bmutil.c,v 1.41 2000/05/09 16:48:24 brian Exp $";
 #endif
 
 #ifndef UNIX
@@ -1463,7 +1463,7 @@ long msgid;
 			m->mbox[msg].status |= BM_RRECEIPT;
 			rip (returnreceipt);	/* strip off <CR> */
 			tprintf ("[Sending return receipt to '%s']\n", returnreceipt);
-			mm = (struct mbx *) mallocw (sizeof (struct mbx));
+			mm = (struct mbx *) callocw (1, sizeof (struct mbx));
 
 			mm->tomsgid = mm->date = mm->origbbs = mm->tofrom = NULLCHAR;
 			mm->origto = returnreceipt;
