@@ -14,7 +14,7 @@
 #include "ftp.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: buckbook.c,v 1.13 1996/12/23 22:44:37 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: buckbook.c,v 1.14 1997/08/19 01:19:22 root Exp $";
 #endif
 
 /*
@@ -948,7 +948,7 @@ char  *call;
         init_Database(NULLCHAR);
 
     tmpnam(file);
-    strcpy(dosfile, file);
+    strncpy(dosfile, file, 20);
     q = dosfile;
 
     while (*q != '\0')  {
