@@ -1,11 +1,12 @@
 #include "global.h"
-#include "files.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: catalog.c,v 1.12 1997/06/28 16:46:13 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: catalog.c,v 1.14 1997/09/07 00:31:16 root Exp $";
 #endif
 
 #ifdef CATALOG
+#include "files.h"
+
 char * catalog (int base, int theindex);
 int catalog_check (void);
 extern unsigned long filelength (int);
@@ -20,18 +21,23 @@ static char stringbuf[256];
 long seekto;
 
 	stringbuf[0] = 0;
-	if (!strfp)	{
-		if ((strfp = fopen (CATALOGfile, READ_BINARY)) == NULLFILE)	{
-			(void) fprintf (stderr, "\n\r\n\007Can't open catalog file '%s'!\n", CATALOGfile);
-			(void) fflush (stderr);
-			kpause (10000);
-			where_outta_here (0, "catalog");
+	do	{
+		if (!strfp)	{
+			if ((strfp = fopen (CATALOGfile, READ_BINARY)) == NULLFILE)	{
+				(void) fprintf (stderr, "\n\r\n\007Can't open catalog file '%s'!\n", CATALOGfile);
+				(void) fflush (stderr);
+				kpause (10000);
+				where_outta_here (0, "catalog");
+			}
 		}
-	}
 
-	seekto = base + theindex;
-	seekto *= 256;
-	fseek (strfp, seekto, SEEK_SET);
+		seekto = base + theindex;
+		seekto *= 256;
+		if (fseek (strfp, seekto, SEEK_SET))
+			/* file seems to have been closed behind out backs! */
+			strfp = NULLFILE;
+	} while (!strfp);
+
 	(void) fread (stringbuf, 1, 256, strfp);
 	return (stringbuf);
 }
