@@ -12,6 +12,11 @@
 int domem (int argc,char *argv[],void *p);
 #endif
 
+#ifdef	APRSD
+/* In aprssrv.c */
+int doaprs (int argc, char *argv[], void *p);
+#endif
+
 /* In arpcmd.c */
 int doarp (int argc,char *argv[],void *p);
 
@@ -19,6 +24,9 @@ int doarp (int argc,char *argv[],void *p);
 int asy_attach (int argc,char *argv[],void *p);
 int doasycomm (int argc,char *argv[],void *p);
 int doasystat (int argc,char *argv[],void *p);
+#ifdef KISS
+int axloop_attach (int argc,char *argv[],void *p);
+#endif
 
 /* In at.c */
 int doat (int argc,char *argv[],void *p);
@@ -26,12 +34,18 @@ int doat (int argc,char *argv[],void *p);
 /* In ax25.c */
 int axip_attach (int argc,char *argv[],void *p);
 
+#ifdef	AXUDP
+/* In axudp.c - 12Mar2001, VE4KLM */
+int axudp_attach (int argc,char *argv[],void *p);
+#endif
+
 /* In ax25aar.c */
 int doax25autoroute (int argc,char *argv[],void *p);
 
 /* In ax25cmd.c */
 int doax25 (int argc,char *argv[],void *p);
 int doaxstat (int argc,char *argv[],void *p);
+int doaxcounters (int argc,char *argv[],void *p);
 int doaxheard (int argc,char *argv[],void *p);
 int doconnect (int argc,char *argv[],void *p);
 int donralias (int argc, char *argv[], void *p);
@@ -151,6 +165,9 @@ int AREAlookup (char *area,int theindex);
 void fwdlockit (char *name);
 void fwdunlockit (char *name);
 
+/* In fopen.c */
+int dofstat (int argc,char *argv[],void *p);
+
 /* In ftpcli.c */
 int doftp (int argc,char *argv[],void *p);
 int doftype (int argc,char *argv[],void *p);
@@ -204,6 +221,7 @@ int doping (int argc,char *argv[],void *p);
 int doifconfig (int argc,char *argv[],void *p);
 int dodetach (int argc,char *argv[],void *p);
 void removetrace (void);
+int dummy_attach (int argc, char *argv[], void *p);
 
 /* In import.c */
 #ifdef BBSIMPORT
@@ -218,6 +236,11 @@ int doipheard (int argc,char *argv[],void *p);
 /* In kiss.c */
 int kiss_attach (int argc,char **argv,void *p);
 
+#ifdef linux
+/* In krnlif.c */
+int krnlif_attach(int argc, char *argv[], void *p);
+#endif
+
 /* In ksubr.c */
 int ps (int argc,char *argv[],void *p);
 int dokstat (int argc,char *argv[],void *p);
@@ -233,13 +256,19 @@ int dopbbs (int argc,char *argv[],void *p);
 #ifdef CALLBOOK
 int doinetcallserver (int argc,char *argv[],void *p);
 #endif
+#ifdef MAILCMDS
+int doarea (int argc, char *argv[], void *p);
+int dombreview (int argc, char *argv[], void *p);
+#endif
 void setMaintenance (void);
 void clearMaintenance (void);
+void quickscan (struct mbx *m, int olduser, int usename);
 
 /* In mailfor.c */
 int dombrline (int argc,char *argv[],void *p);
 
 /* In main.c */
+int doshutdown (int argc,char *argv[],void *p);
 int dodelete (int argc,char *argv[],void *p);
 int dorename (int argc,char *argv[],void *p);
 int doexit (int argc,char *argv[],void *p);
@@ -276,6 +305,9 @@ int dorepeat (int, char **, void *);
 void mail_error (const char *fmt, ...);
 int dosystime (int argc,char *argv[],void *p);
 int DisplayFile (const char *fname,int thesocket);
+int docrashprot (int, char **, void *);
+int shall_we_crash (void);
+void crash_it_already (char const *where);
 #ifdef SETPSINFO
 void setprocname (char *str);
 #endif
@@ -299,6 +331,12 @@ int readhex (char *out,char *in,int size);
 void kmutex_lock (int *key);
 void kmutex_unlock (int *key);
 
+#ifdef NODECALL
+/* In node.c */
+int donode (int argc, char *argv[], void *p);
+int node_incom (int argc, char *argv[], void *p);
+#endif
+
 /* In nntpcli.c */
 int donntp (int argc,char *argv[],void *p);
 
@@ -368,6 +406,11 @@ int pop3start   (int argc,char *argv[],void *p);
 int pop3stop    (int argc,char *argv[],void *p);
 #endif
 
+/* In profile.c */
+int doprofile (int argc,char *argv[],void *p);
+int dombprofile (int argc,char *argv[],void *p);
+int dombpasswd (int argc,char *argv[],void *p);
+
 /* In rarp.c */
 int dorarp (int argc,char *argv[],void *p);
 
@@ -394,7 +437,7 @@ int doregister (int argc,char *argv[],void *p);
 int doregistry (int argc,char *argv[],void *p);
 
 /* In reject.c */
-int reject (const char *cmdstr, int rmtuser);
+int reject (const char *cmdstr, int rmtuser, int xfwd);
 
 /* In reqsvr.c */
 void parseheader (FILE *fp,char *from, char *subject, char *to, char *bid, char *buf,long *startat);
@@ -406,6 +449,18 @@ int dorlogin (int argc,char *argv[],void *p);
 /* In rspfcmd.c */
 int dorspf (int argc,char **argv,void *p);
 
+/* In rtcli.c */
+#ifdef ENCAP
+int routecli0 (int argc, char *argv[], void *p);
+int routecli1 (int argc, char *argv[], void *p);
+#endif
+
+/* In rtserv.c */
+#ifdef ROUTESERVER
+int route0 (int argc, char *argv[], void *p);
+int route1 (int argc, char *argv[], void *p);
+#endif
+
 #ifdef SCC
 /* In scc.c */
 int scc_attach (int argc,char *argv[],void *p);
@@ -453,6 +508,7 @@ int doupload (int argc,char *argv[],void *p);
 void sesflush(void);
 
 /* In smisc.c */
+void server_disconnect_io (void);
 int deleteserver (int *mysocket);
 int installserver (int argc,char *argv[],int *mysocket,const char *listener,
 	int defport, uint32 defaddress, const char *procname,
@@ -533,6 +589,7 @@ void screendaemon (int i, void *v1, void *v2);
 void marquee_display (char *str, int *position);
 int statnews0 (int argc, char *argv[], void *p);
 int statnews1 (int argc, char *argv[], void *p);
+int getStatlines (void);
 
 /* In stats.c */
 #ifdef STATS
@@ -555,6 +612,14 @@ int STATmonthly_msg (int argc,char *argv[],void *p);
 int STATyearly_msg (int argc,char *argv[],void *p);
 int STATgeneral_msg (int argc,char *argv[],void *p);
 #endif
+#ifdef STATS_HTTP
+void STATS_addhttp (int which);
+int STATdaily_http (int argc,char *argv[],void *p);
+int STATweekly_http (int argc,char *argv[],void *p);
+int STATmonthly_http (int argc,char *argv[],void *p);
+int STATyearly_http (int argc,char *argv[],void *p);
+int STATgeneral_http (int argc,char *argv[],void *p);
+#endif
 #ifdef STATS_TFC
 void STATS_addtfc (int which, int amount);
 int STATdaily_tfc (int argc,char *argv[],void *p);
@@ -594,12 +659,17 @@ int term0 (int argc,char *argv[],void *p);
 int term1 (int argc,char *argv[],void *p);
 #endif
 
+/* In timer.c */
+int dotimers (int argc, char *argv[], void *p);
+
 /* In tip.c */
 int dotip (int argc,char *argv[],void *p);
 
 /* In tipmail.c */
 int telnet0 (int argc, char *argv[], void *p);
 int telnet1 (int argc, char *argv[], void *p);
+int fbbtelnet0 (int argc, char *argv[], void *p);
+int fbbtelnet1 (int argc, char *argv[], void *p);
 #ifdef TIPMAIL
 int tipstart (int argc, char *argv[], void *p);
 int tip0 (int argc, char const *argv[], void *p);
