@@ -25,12 +25,15 @@
 #undef TRUE
 
 #ifndef _lint
-static char rcsid[] OPTIONAL = "$Id: curses.c,v 1.20 1997/08/19 01:19:22 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: curses.c,v 1.21 2000/05/09 16:48:25 brian Exp $";
 #endif
 
+#if 0 /* unless ur using *really* old ncurses libs - pre 1.9 or something */
 # ifndef	wbkgdset
 #  define wbkgdset(w,attr) ((w)->_bkgd = (attr))
 # endif
+#endif
+
 # ifndef getattrs
 #  define getattrs(w) ((w)->_attrs)
 # endif
@@ -71,10 +74,33 @@ extern int Numrows, Numcols;
 extern int Keyboard;
 extern int SYSback, SYSfore;
 
+#ifdef PATCURSES /* VE1TTL */
+static void curses_clrscr (const struct sessmgr_sw *sm OPTIONAL, void *dp);
+short init_pairs(void);
+short STATback = COLOR_BLUE;	/* statline colors */
+short STATfore = COLOR_WHITE;
+short SPLITfore = COLOR_WHITE;	/* chatline colors */
+short SPLITback = COLOR_BLUE;
+static chtype colorsplit;
+static chtype colorstat;
+static short pair_main;  /* holds current fg/bg colorpair */
+static short colors[8] =
+{
+	COLOR_BLACK,
+	COLOR_RED,
+	COLOR_GREEN,
+	COLOR_YELLOW,
+	COLOR_BLUE,
+	COLOR_MAGENTA,
+	COLOR_CYAN,
+	COLOR_WHITE
+};
+#endif /* PATCURSES */
 
+#ifndef PATCURSES
 /* colors - this is a mess */
 static int *color_pair_map;
-
+#endif
 
 struct keytrie
 {
@@ -100,6 +126,10 @@ struct curses_data
     } save;
     char parm[8];
     char nparm;
+#ifdef PATCURSES
+    attr_t s_attrs;		/* current attribute */
+    chtype s_bkgd;		/* current background char/attrib pair */ 
+#endif
     char bg;			/* current background */
     char fg;			/* current foreground */
     char flags;
@@ -113,6 +143,7 @@ struct curses_data
 
 static struct keytrie *keys;
 
+#ifndef PATCURSES
 /* mapping of IBM line-drawing characters to curses line drawing */
 /* this is evil: it doesn't use e.g. ACS_HLINE because that's an array ref */
 static chtype ibm_map[128] =
@@ -134,7 +165,7 @@ static chtype ibm_map[128] =
      0,   0,   0,   0,   0,   0,   0,   0,
      0,   0,   0,   0,   0,   0,   0,   0,
 };
-
+#endif
 
 
 /*lint -save -e550 */
@@ -215,8 +246,7 @@ int c;
 
 /*lint -restore */
 
-
-
+#ifndef PATCURSES
 static int
 map_colors(int bg, int fg)
 {
@@ -259,7 +289,7 @@ int cp, cmask;
 #endif
 	return ((int) COLOR_PAIR((unsigned int)(cp + 1)));
 }
-
+#endif /* PATCURSES */
 
 
 static int
@@ -280,9 +310,13 @@ curses_init(const struct sessmgr_sw *sm OPTIONAL)
 		 * up the colors in question...
 		 */
 		if (has_colors() && start_color() != ERR && COLORS >= 8)	{
+#ifdef PATCURSES
+			(void) init_pairs(); /* initialize color pairs */
+#else
 			color_pair_map = mallocw((unsigned int)COLOR_PAIRS * sizeof(int));
 			memset(color_pair_map, -1, ((unsigned int) COLOR_PAIRS) * sizeof(int));
 			(void) map_colors(SYSback, SYSfore); /* default color pair */
+#endif /* PATCURSES */
 		}
 #ifdef RAW_SESSMGR
 		my_term = cur_term;
@@ -320,6 +354,54 @@ curses_init(const struct sessmgr_sw *sm OPTIONAL)
 	return 1;
 }
 
+#ifdef PATCURSES
+/* _ve1ttl - define pairs (1-8) standard colors, and 9 (main pair),
+ * 10 (status pair), 11 (splitline pair).
+ * called initially and after any SYSback change for
+ * the current screen colors to be updated by ncurses
+ */
+#define NUMPAIRS	11
+short init_pairs(void)
+{
+	short x;
+	for (x = 1; x <= 8 && x < COLOR_PAIRS; x++)
+		if (init_pair(x, colors[x - 1], (short) SYSback) == ERR)
+			break;
+	if (x != 9) {
+		fprintf(stderr, "Curses error: only able to initialize to colorpair (%d) !\n", x);
+		return 1;
+	}
+	if (init_pair(x, (short) SYSfore, (short) SYSback) == ERR) {
+		fprintf(stderr, "Curses error: init_pair(%d) main color failed !\n"
+				"SYSfore=%d, SYSback=%d\n", SYSfore, SYSback, x);
+		pair_main = (SYSfore == 7)? 1 : 8;
+		x--;
+	}
+	else
+		pair_main = x;
+	/* status color */
+	if (init_pair(++x, STATfore, STATback) == ERR) {
+		fprintf(stderr, "Curses error: init_pair(%d) status color failed !\n"
+				"STATfore=%d, STATback=%d\n", STATfore, STATback, x);
+		colorstat = (COLOR_PAIR(pair_main) | A_REVERSE);
+		x--;
+	}
+	else
+		colorstat = COLOR_PAIR(x);
+
+	/* splitline color */
+	if (init_pair(++x, SPLITfore, SPLITback) == ERR) {
+		fprintf(stderr, "Curses error: init_pair(%d) splitscreen color failed !\n"
+				"SPLITfore=%d, SPLITback=%d\n", SPLITfore, SPLITback, x);
+		colorsplit = (COLOR_PAIR(pair_main) | A_REVERSE);
+		x--;
+	}
+	else
+		colorsplit = COLOR_PAIR(x);
+
+	return (x == NUMPAIRS)? 0 : x;
+}
+#endif
 
 
 static void
@@ -383,7 +465,14 @@ size_t l;
 	if (!opts)    {
 		/* return printable version of options */
 		buf[0] = '\0';
+#ifdef PATCURSES
+		/* "ansi" default */
+		if (!(cp->flags & C_TTY))
+			strcpy (buf, "ansi");
+		else
+#else
 		if (cp->flags & C_TTY)
+#endif
 			strcpy(buf, "tty");
 		if ((cp->flags & (C_TTY|C_BOLD)) == (C_TTY|C_BOLD))
 			strcat(buf, ",");
@@ -484,6 +573,12 @@ chtype attrs;
 		wiach(sp->win, (chtype) c, sp->flags & C_INS);
 		return;
 	}
+#ifdef PATCURSES
+	if (c == 12)    {  /* ctrl-l */
+		(void) wrefresh(curscr);
+		return;
+	}
+#endif
 	if (c == '\n')    {
 		/* waddch() does clrtoeol() implicitly.  This breaks us. */
 		getyx(sp->win, y, x);
@@ -511,7 +606,11 @@ chtype attrs;
 		sp->flags &= ~(C_ESC|C_CSI);
 		return;
 	}
+#ifdef PATCURSES
+	if (c == 27 && !(sp->flags & C_TTY))    { 
+#else
 	if (c == 27)    {
+#endif
 		sp->flags |= C_ESC;
 		return;
 	}
@@ -525,6 +624,12 @@ chtype attrs;
 	}
 	if (c < 32)
 		return;
+#ifdef PATCURSES
+	if (!(sp->flags & (C_ESC|C_CSI|C_TTY))) {
+		wiach(sp->win, (chtype) c, sp->flags & C_INS);
+		return;
+	}
+#else
 	if (!(sp->flags & (C_ESC|C_CSI)))    {
 		if (c > 127 && ibm_map[c - 128])
 			wiach(sp->win, ibm_map[c - 128] | A_ALTCHARSET, sp->flags & C_INS);
@@ -532,6 +637,7 @@ chtype attrs;
 			wiach(sp->win, (chtype) c, sp->flags & C_INS);
 		return;
 	}
+#endif
 	if (sp->flags & C_ESC)    {
 		/* we only handle '[' */
 		switch (c)	{
@@ -585,7 +691,11 @@ chtype attrs;
 		sp->parm[(int)sp->nparm] = (char) (sp->parm[(int)sp->nparm] * 10 + c - '0');
 		break;
 	    case ';':
+#ifdef PATCURSES
+		sp->parm[(int)(++sp->nparm)] = 0;
+#else
 		sp->parm[(int)(sp->nparm++)] = 0;
+#endif
 		break;
 	    case '?':
 		/* just ignore it for now */
@@ -619,7 +729,11 @@ chtype attrs;
 			    wattrset(sp->win, attrs);
 			    break;
 			case 2:
+#ifdef PATCURSES /* lets not clear everything! */
+				curses_clrscr(sm, sp);
+#else
 			    (void) wclear(sp->win);
+#endif
 			    break;
 			default:
 			    break;
@@ -657,14 +771,21 @@ chtype attrs;
 		break;
 	    case 'm':
 		sp->flags &= ~(C_ESC|C_CSI);
+#ifndef PATCURSES
 		if (!sp->nparm)	{
 		    (void) wattroff(sp->win, A_BOLD|A_DIM|A_UNDERLINE|A_BLINK|A_REVERSE);
 		    break;
 		}
 		for (x = 0; x < sp->nparm; x++)	{
+#else
+		for (x = 0; x <= sp->nparm; x++)	{
+#endif
 		    switch (sp->parm[x])    {
 			    case 0:
 				(void) wattroff(sp->win, A_BOLD|A_DIM|A_UNDERLINE|A_BLINK|A_REVERSE);
+#ifdef PATCURSES
+				wattrset(sp->win, COLOR_PAIR(0));
+#endif
 				break;
 			    case 1:
 				(void) wattron(sp->win, A_BOLD);
@@ -697,7 +818,23 @@ chtype attrs;
 				(void) wattroff(sp->win, A_REVERSE);
 				break;
 			    /* ANSI color sequences? */
-			    /* not for now; curses colors are too complex */
+
+#ifdef PATCURSES
+					/* _ve1ttl background == SYSback */
+					case 30:
+					case 31:
+					case 32:
+					case 33:
+					case 34:
+					case 35:
+					case 36:
+					case 37:
+#ifndef NCURSES_VERSION_MAJOR
+				wbkgdset(sp->win, COLOR_PAIR((sp->parm[x] - 29)));
+#endif
+				wattron(sp->win, COLOR_PAIR((sp->parm[x] - 29)));
+				break;
+#endif
 			    default:
 			        break;
 		    }
@@ -838,12 +975,20 @@ struct curses_data *ssp;
 
 	ssp->bg = (char) SYSback;	/* witness help 'em if they're in an xterm */
 	ssp->fg = (char) SYSfore;
+#ifdef PATCURSES
+	(void) wbkgd(ssp->win, COLOR_PAIR(pair_main));
+	wattrset(ssp->win, COLOR_PAIR(pair_main));
+#else
 	(void) wbkgd(ssp->win, COLOR_PAIR(1));
 	wattrset(ssp->win, COLOR_PAIR(1));
-
+#endif
 	ssp->flags = 0;
 	ssp->save.valid = 0;
 	curscreen = ssp;
+#ifdef PATCURSES
+	ssp->s_attrs = ssp->win->_attrs;
+	ssp->s_bkgd = ssp->win->_bkgd;
+#endif
 	return ssp;
 }
 
@@ -914,12 +1059,49 @@ static void
 curses_window (const struct sessmgr_sw *sm OPTIONAL, void *dp, int x1 OPTIONAL,
 	int y1, int x2 OPTIONAL, int y2)
 {
+#ifdef PATCURSES
+	/* _ve1ttl, pay attention to where we are and set the appropriate
+	 * color attributes.
+	 */
+register struct curses_data *sp;
+	sp = dp;
+	y1--; /* top _marg */
+	y2--; /* bottom _marg */
+	if (sp->win->_tmarg != Numrows-2 && sp->win->_bmarg > 3) {
+		/* we're in the main window */
+		if (y1 != Numrows-2 && y2 >3)
+			return;
+		sp->s_attrs = sp->win->_attrs;
+		sp->s_bkgd = sp->win->_bkgd;
+	}
+
+	(void) wsetscrreg(sp->win, y1, y2);
+	(void) wmove(sp->win, y1, 0);
+
+	if (y1 == Numrows-2) { 	
+		wbkgdset(sp->win, colorsplit);
+		wattrset(sp->win, colorsplit | A_BOLD);
+	}	
+	else if (y2 > 3) {
+		/* we're in the main window, restore saved ch/attrs */
+		sp->win->_bkgd = sp->s_bkgd;
+		sp->win->_attrs = sp->s_attrs;
+	}
+	else {  
+#ifndef NCURSES_VERSION_MAJOR
+		wbkgdset(sp->win, colorstat);
+#endif
+		wattrset(sp->win, colorstat | A_BOLD);
+	}
+	return;
+#else
 WINDOW *w;
 
 	w = ((struct curses_data *) dp)->win;
 	(void) wsetscrreg(w, y1 - 1, y2 - 1);
 	/* ttydriv() assumes the cursor is placed in this window somewhere */
 	(void) wmove(w, y1 - 1, 0);
+#endif /* PATCURSES */
 }
 
 
@@ -954,8 +1136,13 @@ curses_norm (const struct sessmgr_sw *sm OPTIONAL, void *dp)
 static void
 curses_txtattr (const struct sessmgr_sw *sm OPTIONAL, void *dp, int color)
 {
+#ifdef PATCURSES
+	(void) init_pair (pair_main, color & 0x0f, ((unsigned int) color >> 4) & 0x0f);
+	wattrset (((struct curses_data *) dp)->win, COLOR_PAIR(pair_main));
+#else
 	(void) init_pair (1, color & 0x0f, ((unsigned int) color >> 4) & 0x0f);
 	wattrset (((struct curses_data *) dp)->win, COLOR_PAIR(1));
+#endif
 }
 
 
@@ -974,7 +1161,11 @@ curses_bground (const struct sessmgr_sw *sm OPTIONAL, void *dp, int color)
 {
 	((struct curses_data *) dp)->bg = (char) color;
 	curses_txtattr (sm, dp, ((int) (((unsigned int)color) << 4) | (int)((struct curses_data *) dp)->fg));
+#ifdef PATCURSES
+	(void) wbkgd (((struct curses_data *) dp)->win, COLOR_PAIR(pair_main));
+#else
 	(void) wbkgd (((struct curses_data *) dp)->win, COLOR_PAIR(1));
+#endif
 }
 
 
@@ -982,8 +1173,12 @@ static void
 curses_fground (const struct sessmgr_sw *sm OPTIONAL, void *dp, int color)
 {
 	((struct curses_data *) dp)->fg = (char) color;
+#ifdef PATCURSES
+	wattrset (((struct curses_data *) dp)->win, COLOR_PAIR((color <= 7)? (short) color+1 : pair_main ));
+#else
 	curses_txtattr (sm, dp, (int) ((int) (((unsigned int) (int) ((struct curses_data *) dp)->bg) << 4) | color));
 	(void) wbkgd (((struct curses_data *) dp)->win, COLOR_PAIR(1));
+#endif
 }
 
 
