@@ -34,7 +34,7 @@
 #include "session.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: domain.c,v 1.34 1997/08/19 01:19:22 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: domain.c,v 1.36 2001/05/06 16:32:55 brian Exp $";
 #endif
 
 #ifdef UNIX
@@ -266,7 +266,7 @@ dodomain (int argc, char *argv[], void *p)
 
 
 
-int
+static int
 docache (int argc, char *argv[], void *p)
 {
 	return subcmd (Dcachecmds, argc, argv, p);
@@ -676,7 +676,10 @@ int i, j, k;
 				stricmp (search_rrp->rdata.hinfo.os, target_rrp->rdata.hinfo.os);
 			break;
 		case TYPE_MX:
-			i = stricmp (search_rrp->rdata.mx.exch, target_rrp->rdata.mx.exch);
+		    if (!search_rrp->rdata.mx.exch || !target_rrp->rdata.mx.exch)
+			    i= -32764;
+		    else
+			    i = stricmp (search_rrp->rdata.mx.exch, target_rrp->rdata.mx.exch);
 			break;
 		case TYPE_SOA:
 			i = search_rrp->rdata.soa.serial != target_rrp->rdata.soa.serial;
@@ -1768,7 +1771,7 @@ int tried = 0;		/* server list has been retried (count) */
 
 	/* got a response */
 	dp->responses++;
-	dhp = (struct dhdr *) mallocw (sizeof (struct dhdr));
+	dhp = (struct dhdr *) callocw (1, sizeof (struct dhdr));
 
 	(void) ntohdomain (dhp, &bp);	/* Convert to local format */
 
@@ -2193,8 +2196,7 @@ int16 localpref = MAXINT16;
 		rrp = arrp = resolve_rr (sname, TYPE_MX, 1);
 		/* Search this list of rr's for an MX record */
 		while (rrp != NULLRR) {
-			if (rrp->rdlength > 0) {
-				addr = resolve (rrp->rdata.mx.exch);
+			if ((rrp->rdlength > 0) && ((addr = resolve (rrp->rdata.mx.exch)) != 0L)) {
 				/*
 				 * If this is one of our interfaces,
 				 * report our master IP address to avoid
@@ -2463,7 +2465,7 @@ struct rr *qp;
 	}
 	/* Maximum reply size is 512, see rfc1034/1035 */
 	/*    buf = mallocw(512);	*/
-	buf = mallocw (5120);	/* quick patch */
+	buf = callocw (1, 5120);	/* quick patch */
 	len = htondomain (dhdr, buf, 5120);
 	if (len > 5120)  /* insufficient buffer space, we've trashed the arena */
 		where_outta_here (1, "proc_query");
@@ -2509,7 +2511,7 @@ int foo;
 			break;	/* Server closing */
 		if (foo == 0)
 			continue;
-		dhdr = mallocw (sizeof (struct dhdr));
+		dhdr = callocw (1, sizeof (struct dhdr));
 
 		(void) ntohdomain (dhdr, &bp);
 		if (Dtrace) {
@@ -2684,7 +2686,7 @@ FILE *fp;
 	tprintf ("Resolving %s .....\n", argv[1]);
 	if ((address = resolve (argv[1])) == 0L) {
 		tprintf (Badhost, "Domain Nameserver", argv[1]);
-		goto exit;
+		goto alldone;
 	}
 	if (argc > 3) {
 		strncpy (rec_type, argv[3], 20);
@@ -2699,7 +2701,7 @@ FILE *fp;
 
 		if (!Type) {
 			tprintf ("Invalid type %s\n", rec_type);
-			goto exit;
+			goto alldone;
 		}
 	}
 	if (isaddr (argv[2])) {
@@ -2746,7 +2748,7 @@ FILE *fp;
 	tprintf ("Querying server (%s)\n    for \"%s\"  - timeout=%ldms  Maxtries=%d\n\n",
 		 inet_ntoa (address), qrrp->name, timeout, maxtries);
 
-	buf = mallocw (512);
+	buf = callocw (1, 512);
 	len = dns_makequery (0, qrrp, buf, 512);
 	for (x = 0; x < maxtries; x++) {
 		(void) sendto (s, buf, len, 0, (char *) &server_in, sizeof (server_in));
@@ -2766,7 +2768,7 @@ FILE *fp;
 	close_s (s);
 
 	if (rval > 0 && errno != EABORT) {
-		dhp = (struct dhdr *) mallocw (sizeof (struct dhdr));
+		dhp = (struct dhdr *) callocw (1, sizeof (struct dhdr));
 
 		(void) ntohdomain (dhp, &bp);	/* convert to local format */
 
@@ -2799,7 +2801,7 @@ FILE *fp;
 
 	free_rr (qrrp);
 
-exit:
+alldone:
 	if (insession) {
 		(void) keywait (NULLCHAR, 1);
 		freesession (sp);
@@ -2811,7 +2813,7 @@ exit:
 
 
 #ifdef ALLCMD
-int
+static int
 dodomlook (int argc OPTIONAL, char *argv[], void *p)
 {
 char **margv;
