@@ -9,7 +9,7 @@
 #include "enet.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: enet.c,v 1.11 1997/07/31 00:44:20 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: enet.c,v 1.12 2001/05/06 16:32:56 brian Exp $";
 #endif
 
 unsigned char Ether_bdcst[] = { 0xff, 0xff, 0xff, 0xff, 0xff, 0xff };
@@ -19,7 +19,7 @@ static struct mbuf *htonether(struct ether *ether,struct mbuf *data);
 
 
 /* Convert Ethernet header in host form to network mbuf */
-struct mbuf *
+static struct mbuf *
 htonether(
 struct ether *ether,
 struct mbuf *data
