@@ -2,20 +2,20 @@
  * Copyright 1991 Phil Karn, KA9Q
  */
 #include "global.h"
-#ifdef PACKET
+#ifdef ETHER
 #include "mbuf.h"
 #include "enet.h"
 #include "trace.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: enetdump.c,v 1.10 1996/12/23 20:37:36 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: enetdump.c,v 1.11 1997/07/31 00:44:20 root Exp $";
 #endif
 
 void
 ether_dump(fp,bpp,check)
 FILE *fp;
 struct mbuf **bpp;
-int check;	/* Not used */
+int check OPTIONAL;	/* Not used */
 {
 	struct ether ehdr;
 	char s[20],d[20];
@@ -45,7 +45,7 @@ int check;	/* Not used */
 }
 int
 ether_forus(iface,bp)
-struct iface *iface;
+struct iface *iface OPTIONAL;
 struct mbuf *bp;
 {
 	/* Just look at the multicast bit */
