@@ -40,7 +40,7 @@
 #include "delegate.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: expire.c,v 1.27 1997/09/07 21:18:28 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: expire.c,v 1.28 2000/05/09 16:48:25 brian Exp $";
 #endif
 
 int ExpireActive = 0;
@@ -50,7 +50,7 @@ extern char *nntp_name_expansion (char *name);
 extern void updateCtl (const char *who, struct let * info);
 extern int expired;
 
-
+#if 0
 static time_t j_mktime (struct tm *);
 
 /* If you're using BC++ 2.0 or higher, you don't need this,
@@ -91,7 +91,7 @@ struct tm *t;
 	return (days * 86400L + t->tm_hour * 3600L + t->tm_min * 60L - 19 * 3600L);
 #endif
 }
-
+#endif
 
 
 #if (defined(EXPIRY) || defined(DELEGATE))
@@ -304,15 +304,21 @@ int ctlfound = 0;
 						++cp;
 					++cp;
 					t.tm_year = atoi (cp);
-					if (t.tm_year > 99)
-						t.tm_year %= 100;
-
+					if (t.tm_year > 1900)  /* 4 digit year */
+						t.tm_year -= 1900;
+					else {
+						/* Message has two digit year */
+						if (t.tm_year < 70)
+							t.tm_year += 100;
+					}
+                                 
 					while (*cp != ' ')
 						++cp;
 					++cp;
 					t.tm_hour = atoi (cp);
 					t.tm_min = atoi (cp + 3);
 					t.tm_sec = atoi (cp + 6);
+					t.tm_isdst = 0;
 
 #else
 					t.tm_year = atoi (cp + 4);
@@ -320,8 +326,12 @@ int ctlfound = 0;
 					t.tm_min = atoi (cp + 10);
 					t.tm_sec = atoi (cp + 13);
 #endif
-					if ((then = j_mktime (&t)) == (time_t) -1)
+					if ((then = mktime (&t)) == (time_t) -1) {
+						/* For now, print a warning if there is a big problem ! */
+						/* Single line following is here for testing only */
+						tcmdprintf ("Invalid article date in expire\n");
 						break;	/* invalid, delete */
+					}
 					/* Now check against age */
 					if (now - then < (time_t) (age * 86400L))
 						keep = 1;
