@@ -8,11 +8,11 @@
 #include "reject.h"
 #ifdef FBBFWD
 extern int MbForwarded;
-extern int FWDpersonal, FWDbulletins;
+extern int FWDpersonal, FWDbulletins, FWDpmulti;
 
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: fbbfwd.c,v 1.27 1997/09/07 00:31:16 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: fbbfwd.c,v 1.28 2000/05/09 16:48:25 brian Exp $";
 #endif
 
 extern int indexFwdBbs (char *name);
@@ -103,7 +103,7 @@ static const char nodatatosend[] = "FBBFWD: No Data to send. Sending FF to %s\n"
 static const char unexpected[] = "FBB Error: Expected '+, -, or ='. Received \'%c\'.\n";
 static const char errorgettingtemp[] =
 	"FBBFWD: Error getting tmp file.\n"
-	"FBBFWD: We're going to pass this file to sendmsg()\n"
+	"FBBFWD: We're going to pass this file to sendmbmsg()\n"
 	"FBBFWD: We were trying to open %s and failed.\n";
 static const char mailrefused[] = "FBBFWD: bbs mail refused: %s from %s";
 static const char mailsent[] = "PBBS mail sent: %s ";
@@ -395,7 +395,7 @@ eatprompt:
 
 #ifdef FBBCMP
 			if (f->m->sid & MBX_FBBCMP) {
-				/* Open a tmpfile for sendmsg to place       */
+				/* Open a tmpfile for sendmbmsg to place       */
 				(void) tmpnam (txtfile);
 
 				if ((m->quickfile = fopen (txtfile, "w+b")) == NULLFILE) {
@@ -405,7 +405,7 @@ eatprompt:
 					return 0;
 				}
 				/* Prepare the text of the message. */
-				sendmsg (f->m, msglst[i].number, msglst[i].bid);
+				sendmbmsg (f->m, msglst[i].number, msglst[i].bid);
 
 				/* close the file. send_yapp() will re-open it. */
 				(void) fclose (m->quickfile);
@@ -419,7 +419,7 @@ eatprompt:
 				/* Send a subject line. */
 				tprintf ("%s\n", msglst[i].subject);
 				/* Send the text of the message. */
-				sendmsg (f->m, msglst[i].number, msglst[i].bid);
+				sendmbmsg (f->m, msglst[i].number, msglst[i].bid);
 
 				/* Send a ctrl-z ... that is OCTAL(32) */
 				tputs ("\032\n");
@@ -493,7 +493,7 @@ eatprompt:
 #endif
 			}
 			if (msglst[i].accept == fbbYES || msglst[i].accept == fbbNO) {
-				if ((!isarea (msglst[i].area) || msglst[i].type != 'B') && (stricmp (msglst[i].area, "sysop") || !SYSOPprotect)) {
+				if ((!isarea (msglst[i].area) || msglst[i].type != 'B') && (stricmp (msglst[i].area, "sysop") || !SYSOPprotect) && (!FWDpmulti)) {
 					m->mbox[msglst[i].number].status |= BM_DELETE;
 					statusCtl (msglst[i].area, "ctl", &m->mbox[msglst[i].number], msglst[i].number, 0);
 					m->change |= CHG_DELETE;
