@@ -39,6 +39,7 @@ extern const char *LOGdir;		/* log directory */
 extern const char *Maillog;		/* mail log */
 extern const char *Mailqdir;		/* Outgoing mail spool */
 extern const char *Mailqueue;		/* Outgoing mail work files */
+extern const char *Mailrelay;       /* Who we relay mail for */
 extern const char *Mailspool;		/* Incoming mail */
 extern const char *MANdir;		/* Manual pages base directory */
 extern const char *PBBSHelp;		/* PBBS Help file */
@@ -110,6 +111,7 @@ extern const char *GPSfile;		/* All heard GPS position data */
 #endif
 
 #ifdef HOLDMODS
+extern const char *Holdqdir;        /* Held mail queue */
 extern const char *UserHoldFile;	/* file w/user name to hold mail from */
 extern const char *WordHoldFile;	/* file w/words to hold mail if found in */
 #endif
@@ -160,6 +162,7 @@ extern const char *NNTPaccess;
 
 #ifdef NNTPS
 extern const char *NNTPactive;
+extern const char *NNTPdist;
 extern const char *NNTPforward;
 extern const char *NNTPhistory;
 extern const char *NEWS2Mail;
@@ -167,6 +170,7 @@ extern const char *NNTPhelp;
 extern const char *NNTPinfo;
 extern const char *NNTPpointer;
 extern const char *NNTPpoll;
+extern const char *UKIPNEWS2Mail;
 #endif
 
 #if (defined(POP) || defined(POP2CLIENT) || defined(POP2SERVER) || defined(POP3CLIENT) || defined(POP3SERVER))
