@@ -176,7 +176,7 @@ char *cp;
 	for ( ; ; ) {
 		if (task->fp != NULLFILE) {
 			if (fgets (line, 1024, task->fp) == NULLCHAR) {
-				fclose (task->fp);
+				(void) fclose (task->fp);
 				task->fp = NULLFILE;
 				tprintf ("OK\n");
 				continue;
@@ -307,7 +307,7 @@ struct mbuf *bp;
 				}
 				return 0;
 			}
-			if (wp->args < 0)	/* this word takes arguments */
+			if (wp->args < 0) {	/* this word takes arguments */
 				if (task->final) {
 					tputs ("MISSING ARGUMENT\n");
 					return -1;
@@ -316,6 +316,7 @@ struct mbuf *bp;
 					task->nextfkn = wp->fkn;
 					return 0;
 				}
+			}
 			return (*wp->fkn) (task);	/* a normal word */
 		}
 		wp++;
@@ -342,11 +343,12 @@ int ret = 0;
 		return push (&task->stack, (int32) (bp->data +
 					     sizeof (struct vocentry) + 1));
 
-	if (ve->type == FORTH_CONSTANT)
+	if (ve->type == FORTH_CONSTANT) {
 		if (*p & FORTH_INDIRECT)
 			return push (&task->stack, **(int32 **) (p + 1));
 		else
 			return push (&task->stack, *(int32 *) (p + 1));
+	}
 	oldword = task->word;
 	task->final = 0;
 	/* now handling FORTH_WORD */
@@ -466,7 +468,7 @@ pop (struct mbuf **stack, int32 *valp)
 struct mbuf *bp;
 
 	bp = *stack;
-	if (bp->cnt == 0)
+	if (bp->cnt == 0)	{
 		if (bp->next == NULLBUF)
 			return -1;
 		else {
@@ -474,6 +476,7 @@ struct mbuf *bp;
 			(void) free_mbuf (bp);
 			bp = *stack;
 		}
+	}
 	*valp = *((int32 *) bp->data + 64 - bp->cnt--);
 	return 0;
 }
@@ -563,11 +566,11 @@ int32 val1, val2, val3;
 				(void) push (&task->stack, val2 % val1);	/* /MOD operation */
 			return push (&task->stack, val2 / val1);	/* pure division */
 		case '<':
-			return push (&task->stack, val2 < val1);	/*lint !e730 */
+			return push (&task->stack, val2 < val1);
 		case '>':
-			return push (&task->stack, val2 > val1);	/*lint !e730 */
+			return push (&task->stack, val2 > val1);
 		case '=':
-			return push (&task->stack, val2 == val1);	/*lint !e730 */
+			return push (&task->stack, val2 == val1);
 		case 'M':
 		case 'm':
 			if (task->word[1] == 'a' || task->word[1] == 'A')	/* MAX */
@@ -608,12 +611,12 @@ int32 val;
 		case 'n':
 		case 'N':
 			if (task->word[1] == '<')
-				return push (&task->stack, val < 0);	/*lint !e730 */
+				return push (&task->stack, val < 0);
 			if (task->word[1] == '>')
-				return push (&task->stack, val > 0);	/*lint !e730 */
+				return push (&task->stack, val > 0);
 			if (task->word[1] == 'e' || task->word[1] == 'E')
 				return push (&task->stack, -val);	/* NEGATE */
-			return push (&task->stack, !val);	/*lint !e730 * NOT, 0= */
+			return push (&task->stack, !val);	/* NOT, 0= */
 		case '2':
 			if (task->word[1] == '+')
 				return push (&task->stack, val + 2);
@@ -1482,7 +1485,7 @@ struct vocentry *ve;
 	}
 	free_q (&task->vocabulary);
 	if (task->fp != NULLFILE)
-		fclose (task->fp);
+		(void) fclose (task->fp);
 	free_q (&task->pad);
 	return -1;
 }
