@@ -17,7 +17,7 @@
 #include "usock.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: forward.c,v 1.44 1997/06/13 13:24:10 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: forward.c,v 1.52 2001/05/08 12:26:44 brian Exp $";
 #endif
 
 #ifdef MBFWD
@@ -45,7 +45,7 @@ extern int MbBID, MbMID;
 static struct timer fwdtimer;
 static int lastSessionSkipped;
 extern int FWDmode, FWDpersonal, FWDbulletins, FWDreverse, FWDinreverse;
-extern int FWDctlz;
+extern int FWDctlz, FWDpmulti;
 extern char FWDCall[AXALEN];
 
 extern char *Mbhaddress;
@@ -68,6 +68,11 @@ extern int Mfbbcmp;
 extern int PBBSstrict;
 #endif
 
+#ifdef UKIP
+extern int FWDtlines;
+extern int FWDxbid;
+#endif
+
 static void sendtempfile (FILE * newfile, struct mbx * m, int sendit);
 
 static int uselessconnect (struct mbx * m, char *filename);
@@ -100,6 +105,9 @@ extern int indexFwdBbs (char *name);
 extern int makeBBSbid (char *bid, int bidlen, char *line);
 extern void bid_add (char *bid, time_t now, int tofile, char *to);
 extern int msgidcheck (char *string);
+#ifdef UKIP
+void makeTlines (struct mbx *m, int msgn);
+#endif
 
 
 #ifdef CATALOG
@@ -156,7 +164,7 @@ static const char forwardingmailto[] = "PBBS %sforwarding mail to: %s ";
 static const char forwardfailed[] = "PBBS forward failed: %s errno %d";
 static const char badax25iface[] = "Invalid forwarding interface '%s' for %s";
 static const char nosidfound[] = "No SID received from remote system %s - aborting";
-static const char nosidfound2[] = "'No SID' indicates a probably problem with your forwarding script";
+static const char nosidfound2[] = "'No SID' indicates a probable problem with your forwarding script";
 #endif /* CATALOG */
 
 
@@ -283,7 +291,7 @@ sendwithcorrectNL (struct mbx *m, char *str)
  */
 
 void
-sendmsg (struct mbx *m, int msgn, char *thebid)
+sendmbmsg (struct mbx *m, int msgn, char *thebid)
 {
 FILE *oldfile, *newfile;
 char buf[LINELEN], tb[LINELEN], *cp;
@@ -294,7 +302,10 @@ int col, ccnt;
 char c;
 int sendthefile = 0;
 long endofmsg = 0L;
-
+#ifdef UKIP
+int foundt = 0, lastlinewast = 0, blanklines = 0;
+#endif
+	
 	/* point to start and end of this message in file */
 	fseek (m->mfile, m->mbox[msgn].start, 0);
 	if (m->nmsgs > msgn)
@@ -323,11 +334,11 @@ long endofmsg = 0L;
 
 			/* get the ARPA format date/time string */
 			if ((cp = strchr (buf, ';')) != NULLCHAR)
-				strcpy (tb, cp + 1);	/* point to the date of receipt */
+				strncpy (tb, cp + 1, LINELEN);	/* point to the date of receipt */
 
 			/* Get the callsign for the R: line */
 			if (mbxRCall)
-				strcpy (buf, mbxRCall);
+				strncpy (buf, mbxRCall, LINELEN);
 			else
 				(void) pax25 (buf, Mycall);
 			if ((cp = strpbrk (buf, DIGI_IDS)) != NULLCHAR)
@@ -407,6 +418,10 @@ long endofmsg = 0L;
 				case XFORWARD:	/* Do not forward the "X-Forwarded-To:" lines */
 				case STATUS:	/* Don't forward the "Status:" line either */
 				case BBSTYPE:
+				case XBID:
+				case XBBSTO:
+				case XNNTPNEWSGROUPS:
+				case LINECNT:
 				case SUBJECT:
 				case TO:
 				case DATE:
@@ -419,9 +434,14 @@ long endofmsg = 0L;
 					free (cp);
 					/* note fall-through */
 				default:
-					trimrightCR (buf);
+				            /* Don't pass 'X-BBS' headers */
+				    if (strncmp (buf, "X-BBS", 5) == 0)
+					    break;
+				
+				    trimrightCR (buf);
 					sendwithcorrectNL (m, buf);
 					sendthefile = 1;
+				
 			}	/* switch */
 		}		/* Mbsmtptoo */
 	}			/* for */
@@ -438,8 +458,22 @@ long endofmsg = 0L;
 			sendtempfile (newfile, m, sendthefile);
 			return;	/* NO text ??? */
 		}
-		if (strncmp (buf, "R:", 2))	/* No more R: lines! */
-			break;
+		if (strncmp (buf, "R:", 2))	{/* No more R: lines! */
+#ifdef UKIP
+			/* Pass any T: Lines in with the R: Lines     */
+			/* If there are none, make our own if enabled */
+
+			if (strncmp (buf, "T:", 2)) {    /* This is not a T: Line */
+				if ((FWDtlines) && (!foundt))
+					makeTlines (m, msgn);          /* Go make T: lines if none already */
+#endif
+				break;
+#ifdef UKIP
+			}
+			else
+				foundt = 1; /* T: Line in with R: Lines - flag and pass*/
+#endif
+			}
 #ifdef BBSEXPORT
 		if (m->quickfile)
 			sendwithcorrectNL (m, buf);
@@ -516,6 +550,29 @@ long endofmsg = 0L;
 
 		if (!strncmp (buf, "From ", 5))	/* somehow endofmsg didn't work */
 			break;
+#ifdef UKIP
+		/* If we're making our own T: Lines, or if there are T: Lines
+		 * already included in with the R: Lines, kill off any existing
+		 * T: lines near the top of the message that have been separated
+		 * out by another BBS  */
+		
+		if (FWDtlines || foundt) {
+			if (buf[0] == '\n') {
+				blanklines ++;
+				if (lastlinewast) { /* chew any blank line following a T: Line */
+					lastlinewast = 0;
+						continue;
+				}
+			}
+			if ((blanklines < 3) && (strncmp (buf, "T:", 2) == 0)) {  
+				lastlinewast = 1;
+				continue;          /* chew the T: line */
+			}
+			else 
+				lastlinewast = 0;
+		}
+#endif
+				
 #ifdef BBSEXPORT
 		if (m->quickfile)
 			sendwithcorrectNL (m, buf);
@@ -542,7 +599,7 @@ int c;
 #endif
 			(void) sendfile (newfile, m->user, ASCII_TYPE, 0);
 	}
-	fclose (newfile);
+	(void) fclose (newfile);
 }
 
 
@@ -663,12 +720,14 @@ char *bid;			/* Buffer to keep bid */
 int *bul;			/* True if message is in public message area */
 {
 int bulletin = *bul;
-int foundbid = 0;
-int foundmid = 0;
+int foundbid = 0, foundmid = 0, foundto = 0;
 char to[LINELEN], atbbs[LINELEN], from[LINELEN], buf[LINELEN], *cp;
 #ifdef FBBFWD
 char bid2[LINELEN];
 char tmp[40];
+#endif
+#ifdef UKIP
+int xbidlen = 0;
 #endif
 
 	if (m->mfile == NULLFILE)
@@ -690,6 +749,11 @@ char tmp[40];
 			break;	/* envelope finished */
 		switch (htype (buf)) {
 			case TO:
+#ifdef UKIP
+			    if (foundto)
+				    break;
+			case XBBSTO:           /* Use X-BBS-TO in preference to To: */
+#endif
 				trimrightCR (buf);
 				/* The following code tries to parse "To: " lines where the
 				 * address looks like any of the following: "to@atbbs",
@@ -698,20 +762,18 @@ char tmp[40];
 				 */
 				if ((cp = getaddress (buf, 0)) == NULLCHAR)
 					break;
-				strcpy (to, cp);
+				strncpy (to, cp, LINELEN);
 				if ((cp = strchr (to, '%')) != NULLCHAR) {	/* look for a '%' */
-					strcpy (atbbs, cp + 1);
+					strncpy (atbbs, cp + 1, LINELEN);
 					*cp = '\0';	/* "to" ends at the '%' character */
+					if ((cp = strchr (atbbs, '@')) != NULLCHAR)
+						*cp = 0;
 				} else {	/* no '%' but maybe a '@'? */
 					if ((cp = strchr (to, '@')) != NULLCHAR) {
-						strcpy (atbbs, cp + 1);
+						strncpy (atbbs, cp + 1, LINELEN);
 						*cp = '\0';	/* "to" ends at the '@' character */
 					}
 				}
-				if (*atbbs != '\0')	/* either '%' or '@' found */
-					/* cut "atbbs" at the first '@' or '.' character */
-					if ((cp = strpbrk (atbbs, "@.")) != NULLCHAR)
-						*cp = 0;
 
 				/* "to" or "atbbs" should not be more than 6 characters (ALEN).
 				 * If "to" is too long, it might simply be because the area name
@@ -719,11 +781,11 @@ char tmp[40];
 				 * the address on the To: line is in an obscure format that we
 				 * failed to parse (eg '!' character notation.)
 				 */
-				if (strlen (to) > ALEN || (*atbbs && (strlen(atbbs) > ALEN))) {
+				if (strlen (to) > ALEN) {
 #if 0
 					/* Play safe and set "to" and "atbbs" to the area name */
-					strcpy (to, m->area);
-					strcpy (atbbs, m->area);
+					strncpy (to, m->area, LINELEN);
+					strncpy (atbbs, m->area, LINELEN);
 #else
 					/* if "to" or "atbbs" are > 6 character, they are IMPROPER. Delete them */
 					return -2;
@@ -732,7 +794,7 @@ char tmp[40];
 				/* why would we want to add an atbbs if the message doesn't have one originally ?!?! */
 #if 0
 				if (*atbbs == '\0')
-					strcpy (atbbs, to);
+					strncpy (atbbs, to, LINELEN);
 #endif
 
 				to[ALEN] = '\0';
@@ -745,18 +807,41 @@ char tmp[40];
 					if ((cp = strchr (atbbs, '.')) != NULLCHAR)
 						*cp = '\0';	/* cut "atbbs" at first dot */
 				}
+			    foundto = 1;
 				break;
 			case MSGID:
 				if (!foundmid)	{
 					foundmid = 1;
 					trimrightCR (buf);
 					bid[0] = '$';
+					
+					
+					/* Is this clobbering the subject line in export ? */
+#if 0
 					foundbid = makeBBSbid (&bid[1], LINELEN - 1, buf);
+#else
+					foundbid = makeBBSbid (&bid[1], LINELEN - 2, buf);
+#endif
 					/* if a bulletin and not in the history file, add it */
 					if (*bul && !msgidcheck (&bid[1]))
 						bid_add (&bid[1], time ((time_t *)0), 1, m->area);
 				}
 				break;
+#ifdef UKIP
+			case XBID:        /* Use BID from X-BID if present */
+			    xbidlen = strlen (buf);
+				if ((xbidlen > 7) && (xbidlen < 21) && FWDxbid) {
+					foundmid = 1;
+					trimrightCR (buf);
+					bid[0] = '$';
+					strcpy (&bid[1], &buf[7]);
+					bid[13] = '\0';
+					cp = (strchr (bid, '\n'));
+					if (cp)
+						*cp = '\0';
+					break;
+				}
+#endif			
 			case SUBJECT:
 				trimrightCR (buf);
 				if (subj != NULLCHAR) {
@@ -778,7 +863,7 @@ char tmp[40];
 						cp = strpbrk (buf, DIGI_IDS);
 						if (cp)
 							*cp = 0;
-						strcpy (from, buf);
+						strncpy (from, buf, LINELEN);
 					} else
 						(void) findident (cp, 1, from);	/* cp points to from@domain */
 					from[ALEN] = '\0';	/* 6 character limit */
@@ -912,7 +997,7 @@ char tmp[40];
 			strcat (line, &bid[1]);
 		else
 #endif
-			/*    if((m->sid & MBX_MID) || ((bulletin || foundbid) & (m->sid & MBX_SID))) */
+
 		if ((m->sid & MBX_MID) || (bulletin && (m->sid & MBX_SID)))
 			strcat (line, bid);
 #ifdef FBBFWD
@@ -928,7 +1013,8 @@ char tmp[40];
 
 
 
-static int			/* 0 = ok, -1 = problem so disc */
+/* return 0 = ok, -1 = problem so disc */
+static int
 sendmsgtobbs (m, msgn, dest, bulletin)
 struct mbx *m;
 int msgn;
@@ -936,10 +1022,20 @@ char const *dest;		/* Optional destination address to override To: line */
 int bulletin;
 {
 int result = -1;
-char line[64], subj[LINELEN], thebid[LINELEN];
+char line[LINELEN], subj[LINELEN], thebid[LINELEN];
 
-	if (makecl (m, msgn, dest, line, subj, thebid, &bulletin) == -1)
+	if (makecl (m, msgn, dest, line, subj, thebid, &bulletin) < 0)
 		return 0;	/* do not forward this particular message */
+
+	if (thebid[0] == 0)	{
+		if (Mtrace)
+			tcmdprintf ("FWD: Skipping message to %s without a BID: %s\n", fwd_bbsname (m), line);
+		log (m->user, "Skipping message to %s without a BID: %s\n", fwd_bbsname (m), line);
+		return 0;
+	}
+	if (Mtrace)
+		tcmdprintf ("FWD: Sending to %s - %s.\n", fwd_bbsname (m), line);
+
 #ifdef BBSEXPORT
 	if (m->quickfile) {
 		fputs (line, m->quickfile);
@@ -953,7 +1049,12 @@ char line[64], subj[LINELEN], thebid[LINELEN];
 #endif
 	rip (line);
 	if (m->quickfile || recvline (m->user, (unsigned char *) m->line, MBXLINE) != -1) {
+		if (Mtrace)
+			tcmdprintf ("FWD: Received from %s - %s.\n", fwd_bbsname (m), m->line);
+
 		if (m->line[0] == 'O' || m->line[0] == 'o' || (m->sid & MBX_SID) == 0) {
+			if (Mtrace)
+				tcmdprintf ("FWD: Sending message to %s\n", fwd_bbsname (m));
 			/* Got 'OK' or any line if the bbs is unsofisticated */
 #ifdef BBSEXPORT
 			if (m->quickfile)
@@ -961,7 +1062,7 @@ char line[64], subj[LINELEN], thebid[LINELEN];
 			else
 #endif
 				tprintf ("%s\n", subj);
-			sendmsg (m, msgn, &thebid[1]);	/* send the message */
+			sendmbmsg (m, msgn, &thebid[1]);	/* send the message */
 #ifdef BBSEXPORT
 			if (m->quickfile) {
 				fputs ("/EX\n", m->quickfile);
@@ -980,7 +1081,7 @@ char line[64], subj[LINELEN], thebid[LINELEN];
 			while (m->quickfile || recvline (m->user, (unsigned char *) m->line, MBXLINE) != -1)
 				if (ISPROMPT (m->line)) {
 					log (m->user, mailsent, line);
-					if (!bulletin && (stricmp (m->area, "sysop") || !SYSOPprotect)) {
+					if (!bulletin && (stricmp (m->area, "sysop") || !SYSOPprotect) && (!FWDpmulti)) {
 						m->mbox[msgn].status |= BM_DELETE;
 						statusCtl (m->area, "ctl", &m->mbox[msgn], msgn, 0);
 						m->change |= CHG_DELETE;
@@ -1038,8 +1139,14 @@ char *cp;
 struct let *cmsg;
 char line[80];
 
+
 	kwait (NULL);
 	bulletin = isarea (area);	/* public area */
+
+	if (Mtrace && FWDareatrace)
+		tcmdprintf ("FWD: Processing %s message area %s for %s.\n",
+			bulletin ? "Public  " : "Private ", area, fwd_bbsname (m));
+
 	if (bulletin && (!FWDbulletins || !m->fwdbbs->bulletins))
 		return err;
 	if (!bulletin && (!FWDpersonal || !m->fwdbbs->personals))
@@ -1126,7 +1233,7 @@ struct arealist *a;
 		m->mysize = 0;
 	}
 	if (m->fwdbbs || fwdinit (m, 1) != -1) {
-		strcpy (oldarea, m->area);
+		strncpy (oldarea, m->area, 64);
 		sprintf (name, "%s/%s", Mailspool, m->name);
 		(void) nntp_name_expansion (name);
 		strcat (name, ".fwd");
@@ -1191,11 +1298,11 @@ struct arealist *a;
 #endif
 				}
 			}
-			fclose (fwd);
+			(void) fclose (fwd);
 			if (!err)
 				(void) remove (name);
 		} else
-			fclose (fwd);
+			(void) fclose (fwd);
 		fwdunlockit (m->name);
 	}
 	if (m->state != MBX_FORWARD)
@@ -1310,7 +1417,7 @@ int anyvalid = 0;
 					break;
 				}
 			}
-			fclose (fp);
+			(void) fclose (fp);
 		}
 		if (!foundone)	{
 			if (Mtrace)
@@ -1390,7 +1497,7 @@ int retval = 0;
 			fwdfree (&m->fwdbbs);
 			continue;
 		}
-		strcpy (m->name, m->fwdbbs->name);
+		strncpy (m->name, m->fwdbbs->name, 20);
 		*poll = m->fwdbbs->poll;
 		if (m->special)
 			*poll = 1;
@@ -1414,7 +1521,7 @@ dombtimer (int argc, char *argv[], void *p OPTIONAL)
 	fwdtimer.func = (void (*)(void *)) fwdtick;	/* what to call on timeout */
 	fwdtimer.arg = NULL;	/* dummy value */
 	set_timer (&fwdtimer, atol (argv[1]) * 1000L);	/* set timer duration */
-	start_timer (&fwdtimer);/* fire it up */
+	start_detached_timer (&fwdtimer);/* fire it up */
 	return 0;
 }
 
@@ -1435,7 +1542,7 @@ dombkick (int argc OPTIONAL, char *argv[] OPTIONAL, void *p OPTIONAL)
 static void
 fwdtick (void *v OPTIONAL)
 {
-	start_timer (&fwdtimer);/* and restart the timer */
+	start_detached_timer (&fwdtimer);/* and restart the timer */
 	checkforALTs ();
 	(void) forwardreset (0, 0, 0);
 	if (FWDmode)
@@ -1515,7 +1622,7 @@ int nummsgs;
 				log (-1, queueing, bid, f->name, alt->name);
 			}
 		}
-		fclose (fp);
+		(void) fclose (fp);
 		if (!nummsgs) {
 			sprintf (buf, "%s/%s", Mailspool, f->name);
 			(void) nntp_name_expansion (buf);
@@ -1655,7 +1762,8 @@ int skip;
 			if (Mtrace)
 				tcmdprintf ("fwd: to %s\n", m->name);
 
-			(void) newproc ("PBBS forwarding", 3072, startfwd, (int) m->subchannel | (m->special << 8), (void *) 0, (void *) strdup (m->name), 0); /*lint !e701 */
+			sprintf (m->line, "PBBS forwarding: %s", m->name);
+			(void) newproc (m->line, 3072, startfwd, (int) m->subchannel | (m->special << 8), (void *) 0, (void *) strdup (m->name), 0); /*lint !e701 */
 			m->subchannel = NOSUBCHANNEL;
 			kwait (NULL);
 		} else {
@@ -1708,8 +1816,8 @@ struct tm *t;
 		now = time ((time_t *) 0);
 		now += (((long) m->fwdbbs->clockoffset) * 3600L);
 		t = localtime (&now);
-		usprintf (m->user, "C %02d%02d%02d %02d%02d\n", t->tm_year,
-			  t->tm_mon + 1, t->tm_mday, t->tm_hour, t->tm_min);
+	        usprintf (m->user, "C %02d%02d%02d %02d%02d\n", (t->tm_year % 100),
+					  t->tm_mon + 1, t->tm_mday, t->tm_hour, t->tm_min);
 		usflush (m->user);
 		for (;;) {
 			if (recvline (m->user, (unsigned char *) m->line, MBXLINE) == -1)
@@ -1818,6 +1926,7 @@ char export[7];
 int lockedstate;
 #endif
 
+	server_disconnect_io ();
 	poll = a / 256;
 	a %= 256;
 	if ((m = newmbx (1)) == NULLMBX) {
@@ -1833,7 +1942,7 @@ int lockedstate;
 	(void) time (&t);
 	m->special = (char) ((poll == 1) ? poll : 0);
 	m->logontime = (long) t;
-	strcpy (m->name, (char *) v2);
+	strncpy (m->name, (char *) v2, 20);
 
 	strcpy (export, "export");
 
@@ -1879,6 +1988,7 @@ int lockedstate;
 	/* m->user will be closed automatically when this process exits */
 	Curproc->output = Curproc->input = m->user;
 	/* We'll do our own flushing right before we read input */
+	kwait (NULL);
 #ifdef BBSEXPORT
 	if (m->user)
 #endif
@@ -1894,9 +2004,14 @@ int lockedstate;
 #ifdef BBSEXPORT
 	if (!m->user) {
 		m->sid = (MBX_SID | MBX_MID | MBX_HIER_SID);
+#if 0
 		if (!m->special)
+#endif
 			(void) dorevfwd (0, NULL, (void *) m);
-		fclose (m->quickfile);
+		(void) fclose (m->quickfile);
+#if 1
+		rmlock (EXPORTDir, m->name);
+#endif
 		fwdcleanup (m, NULLCHAR);
 		close_s (Curproc->output);
 		return;
@@ -1908,7 +2023,7 @@ int lockedstate;
 	 */
 	for (s = m->fwdbbs->script; s; s = s->next) {
 		if (s->linetype == SCRIPT_SID) {
-			strcpy (m->line, s->string);
+			strncpy (m->line, s->string, 20);
 			(void) mbx_parse (m);	/* interpret it */
 			/* now automatically send OUR SID */
 #ifdef MBFWD
@@ -1926,11 +2041,11 @@ int lockedstate;
 			int checkbad = 0;
 
 			bad[0] = 0;
-			strcpy (good, s->string);
+			strncpy (good, s->string, 80);
 			if ((myptr = strchr (good, '|')) != NULLCHAR) {
 				/* negative search string found */
 				*myptr++ = 0;
-				strcpy (bad, myptr);
+				strncpy (bad, myptr, 80);
 				checkbad = 1;
 			}
 			timeout = s->timeout;
@@ -2041,18 +2156,22 @@ adjust:
 				break;
 		}
 	} else	{
-		/* if we get here and have NOT received a SID, we have a
-		   screwed up forwarding script, or the remote has a SERIOUS
-		   breach of the forwarding protocol. Since we do NOT know the
-		   capabilities of the remote machine, we abort! */
-		log (m->user, nosidfound, fwd_bbsname(m));
-		log (m->user, nosidfound2);
-		tcmdprintf (nosidfound, fwd_bbsname(m));
-		tcmdprintf ("\n");
-		tcmdprintf (nosidfound2);
-		tcmdprintf ("\n");
-		fwdcleanup (m, NULLCHAR);
-		return;
+		/* if the sysop has told us that this is a dumb PMS, then
+		   we will ignore the lack of a SID */
+		if (!m->fwdbbs->dumbpms)	{
+			/* if we get here and have NOT received a SID, we have a
+			   screwed up forwarding script, or the remote has a SERIOUS
+			   breach of the forwarding protocol. Since we do NOT know the
+			   capabilities of the remote machine, we abort! */
+			log (m->user, nosidfound, fwd_bbsname(m));
+			log (m->user, nosidfound2);
+			tcmdprintf (nosidfound, fwd_bbsname(m));
+			tcmdprintf ("\n");
+			tcmdprintf (nosidfound2);
+			tcmdprintf ("\n");
+			fwdcleanup (m, NULLCHAR);
+			return;
+		}
 	}
 		
 	/* start the actual forwarding */
@@ -2143,7 +2262,8 @@ char namebuf[512];
 		return -1;
 	switch (*argv[0]) {
 		case 'f':
-			m->fwdbbs->limittype = FWDTYPE_FBBNON;		/*lint !e616 */
+			m->fwdbbs->limittype &= ~FWDTYPE_XFWD;
+			/* fall through */
 		case 't':
 			sp.in->sin_family = AF_INET;
 			{
@@ -2240,6 +2360,10 @@ char namebuf[512];
 #ifdef BBSEXPORT
 		case 'e':
 			/* open current export file */
+#if 1
+		    if (mlock (EXPORTDir, m->name))
+			    return -1;
+#endif
 			sprintf (namebuf, "%s/%s.exp", EXPORTDir, m->name);
 			m->quickfile = fopen (namebuf, APPEND_TEXT);
 			if (m->quickfile) {
@@ -2252,11 +2376,10 @@ char namebuf[512];
 		default:
 			return -1;
 	}
-	if (*argv[0] == 'f')
-#if 1
-		(void) seteol (m->user, "\r");
-#endif
 	(void) sockmode (m->user, SOCK_ASCII);
+	if (*argv[0] == 'f')
+		(void) seteol (m->user, "\r\n");
+
 	if (connect (m->user, sp.p, len) == -1) {
 		log (m->user, forwardfailed, sockerr (m->user), errno);
 		close_s (m->user);
@@ -2298,7 +2421,7 @@ long size, totsize = 0;
 							size += atol (++cp);
 					}
 				}
-			fclose (fp);
+			(void) fclose (fp);
 		}
 		totsize += size;
 		if (size)
@@ -2371,21 +2494,125 @@ int cur = 0;
 	return retval;
 }
 
+#ifdef UKIP
+void
+makeTlines (struct mbx *m, int msgn)
+{
+fpos_t filepos;
+char buf [LINELEN], Tnewsgpline [LINELEN], Tmsgidline [LINELEN];
+char Tfromline [LINELEN];
+int x, foundt = 0;
+	
+	/* Save the 'input' file position */
+	fgetpos (m->mfile, &filepos);
+	
+	Tnewsgpline [0] = '\0';
+	Tmsgidline  [0] = '\0';
+	Tfromline   [0] = '\0';
+	
+	fseek (m->mfile, m->mbox[msgn].start, 0); /* Rewind to the message start */
+	
+	/* Try and recover any original 'T:' lines */
+	(void) fsetpos (m->mfile, &filepos);
+	if (look_for_t_line (buf, sizeof (buf), m->mfile, Hdrs[NEWSGROUPS]) == 0) {
+		sprintf (Tnewsgpline, "T:%s%s", Hdrs[NEWSGROUPS], buf + 14);
+		foundt = 1;
+	}
+	(void) fsetpos (m->mfile, &filepos);
+	if (look_for_t_line (buf, sizeof (buf), m->mfile, Hdrs[MSGID]) == 0) {
+		sprintf (Tmsgidline, "T:%s%s", Hdrs[MSGID], buf + 14);
+		foundt = 1;
+	}
+	(void) fsetpos (m->mfile, &filepos);
+	if (look_for_t_line (buf, sizeof (buf), m->mfile, Hdrs[FROM]) == 0) {
+		sprintf (Tfromline, "T:%s%s", Hdrs[FROM], buf + 8);
+		foundt = 1;
+	}
+	
+   /* If there were no T: lines in the original - make our own */
+	
+	if (!foundt) {
+		/* reset the file position to the top of the message */
+		fseek (m->mfile, m->mbox[msgn].start, 0);
+		if (Mtrace)
+			tcmdprintf ("FWD: Generating T: Lines from Headers\n");
+	
+		for (;;) {
+			/* read a line */
+			if (fgets (buf, sizeof (buf), m->mfile) == NULLCHAR)
+				break;
+			if (*buf == '\n')	/* last header line */
+				break;
+			
+			kwait (NULL);
+			switch (htype (buf)) {
+				case XNNTPNEWSGROUPS:
+				    trimrightCR (buf);
+				    sprintf (Tnewsgpline, "T:%s", buf + 7);
+				    break;
+				case MSGID:
+				    trimrightCR (buf);
+					sprintf(Tmsgidline, "T:%s", buf);
+				    break;
+				case FROM:
+				    trimrightCR (buf);
+					sprintf(Tfromline, "T:%s", buf);
+				    break;
+
+				default:
+			}
+		}
+	} /* foundt */
+	
+	else if (Mtrace)
+		tcmdprintf ("FWD: Regenerating T: lines from those already found\n");
+#if 0	
+	/* Check we haven't overrun into the next message,
+	 * then write the T: lines to the output */
+	
+	if ((ftell (m->mfile)) > (m->mbox[msgn + 1].start)) { 
+		if (Mtrace)
+			tcmdprintf ("FWD: T: Line generator overshot to next message\n");
+		x = fsetpos (m->mfile, &filepos); /* Reset the file pointer */
+		return;
+	}
+#endif	
+#ifdef BBSEXPORT
+	if (m->quickfile) {
+		if (*Tmsgidline != '\0')
+			sendwithcorrectNL (m, Tmsgidline);
+		if (*Tnewsgpline != '\0')
+			sendwithcorrectNL (m, Tnewsgpline);
+		if (*Tfromline != '\0')
+			sendwithcorrectNL (m, Tfromline);
+
+	}
+				else
+#endif
+		if (*Tmsgidline != '\0')
+			usputs (m->user, Tmsgidline);
+		if (*Tnewsgpline != '\0')
+			usputs (m->user, Tnewsgpline);
+		if (*Tfromline != '\0')
+			usputs (m->user, Tfromline);
+	
+	x = fsetpos (m->mfile, &filepos); /* Reset the file pointer to where it was */
+	return;
+}
+#endif
+
 #endif /*MBFWD*/
 
-
-
 void
 fwdlockit (char *name)
 {
 	while (mlock (Mailspool, name))
-		kpause (1000L / MSPTICK);	/* Wait one second and try again */
+		kpause (1000L);		/* Wait one second and try again */
 }
 
-
-
 void
 fwdunlockit (char *name)
 {
 	rmlock (Mailspool, name);
 }
+
