@@ -20,7 +20,7 @@ char *fwd_bbsname (struct mbx *m);
 int fwdinit (struct mbx *m, int try);
 void mark_forwarded (FILE *fp,long ind, char thetype);
 int makecl (struct mbx *m,int msgn,char const *dest,char *line,char *subj,char *bid,int *bul);
-void sendmsg (struct mbx *m,int msgn,char *thebid);
+void sendmbmsg (struct mbx *m,int msgn,char *thebid);
 int checksubchannel (struct mbx *m, int assignit);
 void releasesubchannel (struct mbx *m);
 int cutofffwding (struct mbx *m);
