@@ -20,7 +20,7 @@
 #include "files.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: gps.c,v 1.20 1997/08/19 01:19:22 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: gps.c,v 1.21 2001/05/06 16:32:56 brian Exp $";
 #endif
 
 #define GPSDIAG 1
@@ -43,7 +43,7 @@ static int dogpsstr (int argc,char *argv[],const char *label, const char *descri
 #ifdef GPSDIAG
 static void pprintf (const char *str, char *arg);
 
-void
+static void
 pprintf (str, arg)
 const char *str;
 char *arg;
@@ -125,10 +125,6 @@ int response = 1;
 }
 
 
-#ifdef MSDOS
-#pragma warn -rch
-#endif
-
 /* Start GPS on serial line */
 int
 GPSstart(argc,argv,p)
@@ -217,10 +213,6 @@ int (*rawsave)(struct iface *,struct mbuf *);
 #endif
 }
 
-#ifdef MSDOS
-#pragma warn .rch
-#endif
-
 int
 GPSstop(argc,argv,p)
 int argc OPTIONAL;
