@@ -1,12 +1,7 @@
 #include <stdio.h>
-#ifdef __bsdi__
+#ifndef _lint
 #include <stdlib.h>
 #endif
-#ifdef  __STDC__
-#define x      x
-#else
-#define x      ()
-#endif
 
 #ifndef OPTIONAL
 #define OPTIONAL
@@ -14,10 +9,12 @@
 
 #include <string.h>
 #include "md5.c"
+#undef fopen
+#undef fclose
 
 
 #if !defined(_lint)
-static char hashrcsid[] OPTIONAL = "$Id: hasher.c,v 1.10 1997/06/28 16:46:13 root Exp root $";
+static char hashrcsid[] OPTIONAL = "$Id: hasher.c,v 1.11 1997/07/31 00:44:20 root Exp $";
 #endif
 
 char *savedbasename;
