@@ -5,8 +5,8 @@
 #undef	PROCTRACE		/* kernel debugging */
 
 #include "global.h"
-#ifdef SETPSINFO
 #include "commands.h"
+#ifdef SETPSINFO
 #include "timer.h"
 #endif
 #include "mbuf.h"
@@ -19,19 +19,26 @@
 #endif
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: kernel.c,v 1.20 1997/01/19 21:13:05 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: kernel.c,v 1.24 1997/09/14 14:37:46 root Exp $";
 #endif
 
 struct proc *Curproc;		/* Currently running process */
 struct proc *Rdytab;		/* Processes ready to run (not including curproc) */
 struct proc *Waittab[PHASH];	/* Waiting process list */
 struct proc *Susptab;		/* Suspended processes */
+static struct proc *Rdytail;
+static struct proc *Waittail[PHASH];
+static struct proc *Susptail;
 static struct mbuf *Killq;
 
 #ifdef SETPSINFO
 extern char shortversion[];
 #endif
 
+
+extern void stopalltimers (struct proc *pp);
+extern void tnosfcloseall (struct proc *p);
+int valid_proc (struct proc *pp);
 static void addproc (struct proc * entry);
 static void delproc (struct proc * entry);
 static int procsigs (void);
@@ -54,14 +61,13 @@ register struct proc *pp;
 	/* Create name */
 	pp->name = strdup (name);
 
+	/* Initialize the magic numbers */
+	pp->magic1 = PROC_MAGIC1;
+	pp->magic2 = PROC_MAGIC2;
+
 #ifdef UNIX
-#ifdef linux
-	pp->stksize = 0xC0000000LU;
-	pp->stack = (void *) 0xC0000000LU;
-#else
-	pp->stksize = 0x80000000LU;
-	pp->stack = (void *) 0x80000000LU;
-#endif	/* linux */
+	pp->stksize = STACKBASE;
+	pp->stack = (void *) STACKBASE;
 #else	/* UNIX */
 
 #ifdef TNOS_68K
@@ -86,15 +92,15 @@ register struct proc *pp;
  * on the stack so they can be seen by a C function.
  */
 struct proc *
-newproc (name, stksize, pc, iarg, parg1, parg2, freeargs)
-const char *name;		/* Arbitrary user-assigned name string */
-unsigned int stksize;		/* Stack size in words to allocate */
-void (*pc) (int, void *, void *);	/* Initial execution address */
-int iarg;			/* Integer argument (argc) */
-void *parg1;			/* Generic pointer argument #1 (argv) */
-void *parg2;			/* Generic pointer argument #2 (session ptr) */
-int freeargs;			/* If set, free arg list on parg1 at termination */
-{
+newproc (
+const char *name,			/* Arbitrary user-assigned name string */
+unsigned int stksize,			/* Stack size in words to allocate */
+void (*pc) (int, void *, void *),	/* Initial execution address */
+int iarg,				/* Integer argument (argc) */
+void *parg1,				/* Generic pointer argument #1 (argv) */
+void *parg2,				/* Generic pointer argument #2 (session ptr) */
+int freeargs				/* If set, free arg list on parg1 at termination */
+) {
 register struct proc *pp;
 int i;
 
@@ -104,25 +110,20 @@ int i;
 	/* Create name */
 	pp->name = strdup (name);
 
+	/* Initialize the magic numbers */
+	pp->magic1 = PROC_MAGIC1;
+	pp->magic2 = PROC_MAGIC2;
+
 	/* Allocate stack */
-#if defined(UNIX) || defined(MSDOS)
 	if (stksize) {
 		stksize *= 2;
 		stksize = (stksize < 1024) ? 1024 : stksize;
 	}
 	stksize += 3072;
-#endif
-#ifdef TNOS_68K
-	stksize += 128;
-#endif
 
-#if 0	/* was def __DJGPP__ */
-	pp->stksize = max(stksize,32768);/*****/
-	if ((pp->stack = (int16 *) mallocw (sizeof (int32) * pp->stksize)) == NULL) {
-#else
+	stksize = (stksize + 3) & ~3;
 	pp->stksize = stksize;
 	if ((pp->stack = (int16 *) mallocw (sizeof (int16) * pp->stksize)) == NULL) {
-#endif
 		free (pp->name);
 		free ((char *) pp);
 		return NULLPROC;
@@ -131,14 +132,19 @@ int i;
 	for (i = 0; (unsigned) i < stksize; i++)
 		pp->stack[i] = STACKPAT;
 
-	/* Do machine-dependent initialization of stack */
-	psetup (pp, iarg, parg1, parg2, pc);
-
+	pp->func = pc;
 	pp->freeargs = freeargs;
 	pp->iarg = iarg;
 	pp->parg1 = parg1;
 	pp->parg2 = parg2;
 
+	/* Task initially runs with interrupts on */
+	pp->i_state = 1;
+
+	/* Do machine-dependent initialization of stack */
+	psetup (pp);
+
+
 	/* Inherit creator's input and output sockets */
 	(void) usesock (Curproc->input);
 	pp->input = Curproc->input;
@@ -176,8 +182,9 @@ killproc (register struct proc *pp)
 {
 char **argv;
 
-	if (pp == NULLPROC)
+	if (!valid_proc (pp))
 		return;
+
 	/* Don't check the stack here! Will cause infinite recursion if
 	 * called from a stack error
 	 */
@@ -185,15 +192,17 @@ char **argv;
 	if (pp == Curproc)
 		killself ();	/* Doesn't return */
 
-	/* Close any open sockets */
+	/* Stop alarm clock in case it's running (also done in killself() */
+	stop_timer (&pp->alarm);
+	stopalltimers (pp);
+
+	/* Close any open sockets and files */
 	freesock (pp);
+	tnosfcloseall (pp);
 
 	close_s (pp->input);
 	close_s (pp->output);
 
-	/* Stop alarm clock in case it's running */
-	stop_timer (&pp->alarm);
-
 	/* Alert everyone waiting for this proc to die */
 	ksignal (pp, 0);
 
@@ -207,6 +216,7 @@ char **argv;
 			free (*argv++);
 		free (pp->parg1);
 	}
+
 	if (pp->freeargs == 2)
 		free (pp->parg2);
 	free (pp->name);
@@ -224,12 +234,26 @@ void
 killself ()
 {
 register struct mbuf *bp;
+char *cp;
 
 	if (Curproc != NULLPROC) {
+#if 0
+		/* Stop alarm clock in case it's running (also done in killproc() */
+		stop_timer (&Curproc->alarm);
+		stopalltimers (Curproc);
+#endif
 		bp = pushdown (NULLBUF, sizeof (Curproc));
 		memcpy (bp->data, (char *) &Curproc, sizeof (Curproc));
 		enqueue (&Killq, bp);
 	}
+
+	cp = (char *) mallocw (strlen (Curproc->name) + 1 + strlen (" (zombie)"));
+	if (cp)	{
+		sprintf (cp, "%s (zombie)", Curproc->name);
+		chname (Curproc, cp);
+		free (cp);
+	}
+
 	/* "Wait for me; I will be merciful and quick." */
 	for (;;)
 		kwait (NULL);
@@ -244,6 +268,7 @@ killer (int i OPTIONAL, void *v1 OPTIONAL, void *v2 OPTIONAL)
 struct proc *pp;
 struct mbuf *bp;
 
+	server_disconnect_io ();
 	for ( ; ; ) {
 		while ((volatile struct mbuf *) Killq == NULLBUF)
 			kwait (&Killq);
@@ -261,8 +286,9 @@ struct mbuf *bp;
 void
 suspend (struct proc *pp)
 {
-	if (pp == NULLPROC)
+	if (!valid_proc (pp))
 		return;
+
 	if (pp != Curproc)
 		delproc (pp);	/* Running process isn't on any list */
 	pp->state |= SUSPEND;
@@ -278,11 +304,16 @@ suspend (struct proc *pp)
 void
 resume (struct proc *pp)
 {
-	if (pp == NULLPROC)
+	if (!valid_proc (pp))
 		return;
-	delproc (pp);		/* Can't be Curproc! */
+
+	if (pp != Curproc)
+		delproc (pp);		/* Can't be Curproc! */
 	pp->state &= ~SUSPEND;
-	addproc (pp);
+	if (pp != Curproc)
+		addproc (pp);	/* kwait will do it for us */
+	else
+		kwait (NULL);
 }
 
 
@@ -293,7 +324,7 @@ resume (struct proc *pp)
 void
 alert (struct proc *pp, int val)
 {
-	if (pp == NULLPROC)
+	if (!valid_proc (pp))
 		return;
 
 #ifdef	PROCTRACE
@@ -306,6 +337,8 @@ alert (struct proc *pp, int val)
 	pp->event = 0;
 	if (pp != Curproc)
 		addproc (pp);
+	else
+		kwait (NULL);
 }
 
 
@@ -355,9 +388,9 @@ int i_state;
 	 * waiting for, this will wake us back up
 	 */
 	(void) procsigs();
-	if(event == NULL){
+	if (event == NULL){
 		/* We remain runnable */
-		if(Rdytab == NULL){
+		if (Rdytab == NULL) {
 			/* Nothing else is ready, so just return */
 			Ksig.kwaitnops++;
 			restore(i_state);
@@ -374,9 +407,6 @@ int i_state;
 		 * to prevent deadlock, but it restores our state
 		 * before returning.
 		 */
-#if 0	/* !defined(UNIX) */	/* && !defined(__DJGPP__) */
-		kbint ();	/***/
-#endif
 		giveup();
 		/* Process signals that occurred during the giveup() */
 		(void) procsigs();
@@ -611,37 +641,80 @@ chname (struct proc *pp, const char *newname)
 
 
 
+int
+valid_proc (struct proc *pp)
+{
+	if (pp == NULLPROC)
+		return 0;
+	if (pp->magic1 != PROC_MAGIC1 || pp->magic2 != PROC_MAGIC2)
+		return 0;
+	if (pp->state > (SUSPEND + 1))
+		return 0;
+	return 1;
+}
+
+
+
 /* Remove a process entry from the appropriate table */
 static void
 delproc (entry)
 register struct proc *entry;	/* Pointer to entry */
 {
 int i_state;
+struct proc *next = NULLPROC;
+struct proc *prev = NULLPROC;
 
-	if (entry == NULLPROC)
+	if (!valid_proc (entry))
 		return;
 
 	i_state = disable ();
-	if (entry->next != NULLPROC)
-		entry->next->prev = entry->prev;
-	if (entry->prev != NULLPROC)
-		entry->prev->next = entry->next;
+
+	if (valid_proc (entry->prev))
+		prev = entry->prev;
+
+	if (valid_proc (entry->next))	{
+		entry->next->prev = prev;
+		next = entry->next;
+	}
+
+	if (prev != NULLPROC)
+		prev->next = next;
 	else {
 		switch (entry->state) {
 			case READY:
-				Rdytab = entry->next;
+				Rdytab = next;
 				break;
 			case WAITING:
-				Waittab[phash (entry->event)] = entry->next;
+				Waittab[phash (entry->event)] = next;
 				break;
 			case SUSPEND:
 			case SUSPEND | WAITING:
-				Susptab = entry->next;
+				Susptab = next;
 				break;
 			default:
 				break;
 		}
 	}
+	entry->next = entry->prev = NULLPROC;
+
+	switch (entry->state) {
+		case READY:
+			if (entry == Rdytail)
+				Rdytail = prev;
+			break;
+		case WAITING:
+			if (entry == Waittail[phash (entry->event)])
+				Waittail[phash (entry->event)] = prev;
+			break;
+		case SUSPEND:
+		case SUSPEND | WAITING:
+			if (entry == Susptail)
+				Susptail = prev;
+			break;
+		default:
+			break;
+	}
+
 	restore (i_state);
 }
 
@@ -652,41 +725,50 @@ static void
 addproc (entry)
 register struct proc *entry;	/* Pointer to entry */
 {
-register struct proc *pp;
-struct proc **head;
+struct proc **head, **tail;
 int i_state;
 
-	if (entry == NULLPROC)
+	if (!valid_proc (entry))
 		return;
 
 	switch (entry->state) {
 		case READY:
 			head = &Rdytab;
+			tail = &Rdytail;
 			break;
 		case WAITING:
 			head = &Waittab[phash (entry->event)];
+			tail = &Waittail[phash (entry->event)];
 			break;
 		case SUSPEND:
 		case SUSPEND | WAITING:
 			head = &Susptab;
+			tail = &Susptail;
 			break;
 		default:
 			head = 0;	/* silence warning */
+			tail = 0;
 			break;
 	}
 	if (head) {
 		entry->next = NULLPROC;
 		i_state = disable ();
-		if (*head == NULLPROC) {
+		if (!valid_proc (*head)) {
+			if (*head && shall_we_crash())
+				crash_it_already ("corrupted process table");
 			/* Empty list, stick at beginning */
 			entry->prev = NULLPROC;
 			*head = entry;
+			if (tail)		/* should always be true */
+				*tail = entry;
 		} else {
-			/* Find last entry on list */
-			for (pp = *head; pp->next != NULLPROC; pp = pp->next)
-				;
-			pp->next = entry;
-			entry->prev = pp;
+			if (tail)	{	/* should always be true */
+				if (!valid_proc(*tail))
+					crash_it_already ("corrupted process table");
+				(*tail)->next = entry;
+				entry->prev = *tail;
+				*tail = entry;
+			}
 		}
 		restore (i_state);
 	}
