@@ -7,7 +7,7 @@
 #include "proc.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: ksubr.c,v 1.30 1997/09/14 14:37:46 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: ksubr.c,v 1.31 2001/05/14 19:08:40 brian Exp $";
 #endif
 
 void proc_launch (void);
@@ -161,8 +161,8 @@ char *cp;
 	TNOS_SP(pp) = (long) cp;
 	TNOS_PC(pp) = (long) proc_launch;
 #else
-	TNOS_SP(pp) = (void *) cp;
-	TNOS_PC(pp) = (void *) proc_launch;
+	TNOS_SP(pp) = (int) cp;
+	TNOS_PC(pp) = (int) proc_launch;
 #endif
 #ifdef TNOS_EBP
 	TNOS_EBP(pp) = 0;		/* Anchor stack traces */
