@@ -32,7 +32,7 @@
 #undef  DEBUG2
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: lzhuf.c,v 1.15 1996/12/29 02:47:22 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: lzhuf.c,v 1.17 2001/05/06 16:32:56 brian Exp $";
 #endif
 
 #if defined(CATALOG) && !defined(STANDALONE)
@@ -523,7 +523,7 @@ unsigned first;
 
 
 /* increment frequency of given code by one, and update tree */
-void 
+static void 
 lzhuf_update (struct lzhufstruct *lzhuf, int c)
 {
 int i, j, k, l;
@@ -745,8 +745,8 @@ unsigned long int filesize = 0;
 		}
 	} while (len > 0);
 	EncodeEnd (lzhuf);
-	fclose (lzhuf->iFile);
-	fclose (lzhuf->oFile);
+	(void) fclose (lzhuf->iFile);
+	(void) fclose (lzhuf->oFile);
 
 	if (lzhuf->iFileSize == 0)
 		lzhuf->iFileSize = 1;
@@ -832,8 +832,8 @@ long int filesize = 0;
 		fputs ("\n/EX\n", lzhuf->oFile);
 #endif
 
-	fclose (lzhuf->iFile);
-	fclose (lzhuf->oFile);
+	(void) fclose (lzhuf->iFile);
+	(void) fclose (lzhuf->oFile);
 
 	if (count == 0)
 		count = 1;
@@ -987,13 +987,13 @@ FILE *debug;
 #endif
 
 	/* Terminate. */
-	fclose (binFile);
+	(void) fclose (binFile);
 
 	/* Delete binFileName */
 	unlink (binFileName);
 
 #ifdef DEBUG2
-	fclose (debug);
+	(void) fclose (debug);
 #endif
 	free (f->tmpBuffer);
 	/* Set the socket back to it's orginal mode. */
@@ -1119,7 +1119,7 @@ int usock;
 				tcmdprintf ("FBBCMP: YAPP Message Checksum verified\n");
 			/* Close the data file. */
 			if (iFile)
-				fclose (iFile);
+				(void) fclose (iFile);
 			iFile = NULLFILE;
 
 			/* We're done with this message. Return. */
@@ -1141,7 +1141,7 @@ int usock;
 		}
 	}
 	if (iFile != NULLFILE)
-		fclose (iFile);
+		(void) fclose (iFile);
 
 	/* delete compressed file. */
 	unlink (f->iFile);
@@ -1247,7 +1247,7 @@ int16 newchecksum = 0;
 		tputc (uchar (c));
 
 	/* Terminate. */
-	fclose (binFile);
+	(void) fclose (binFile);
 
 	/* Delete binFileName */
 	unlink (binFileName);
@@ -1288,7 +1288,7 @@ int usock;
 		fputc (c, iFile);
 	}
 
-	fclose (iFile);
+	(void) fclose (iFile);
 	AllocDataBuffers (f);
 	rc = Decode (usock, f->iFile, f->oFile, f->lzhuf, 0, Xtrace);
 	FreeDataBuffers (f);
