@@ -17,10 +17,8 @@
 #endif
 #ifdef UNIX
 #include <sys/stat.h>
-#ifdef BSD
 #include <signal.h>
 #endif
-#endif
 #include <stdarg.h>
 #include "mbuf.h"
 #include "timer.h"
@@ -60,8 +58,12 @@
 #include "slip.h"
 #include "nrs.h"
 
+#ifdef	AXUDP
+#include "axudp.h"
+#endif
+
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: main.c,v 1.55 1997/09/14 14:37:46 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: main.c,v 1.60 2001/05/14 17:49:53 brian Exp $";
 #endif
 
 
@@ -78,7 +80,7 @@ extern int32 LastIO;
 void reset_all_ax25 (void);
 #endif
 
-static char symname[] = "$Name: Release2_30 $";
+static char symname[] = "$Name:  $";
 
 extern int Warnings;
 static int CrashProtect = 0;
@@ -101,6 +103,10 @@ static int UpdateTimeout = 30;
 extern int getcolor (char *color);
 extern int SYSback, SYSfore;
 
+#ifdef PATCURSES
+extern short STATback, STATfore, SPLITfore, SPLITback;
+#endif
+
 #ifdef RLINE
 extern void ReadFwdBbs (void);
 #endif
@@ -194,6 +200,12 @@ extern uint32 *axipaddr;
 extern int AXIPlinks;
 #endif
 
+#ifdef AXUDP
+/* 12Mar2001, VE4KLM */
+extern AXUDPCFG *axudpcfg;
+extern int AXUDPlinks;
+#endif
+
 extern int mbxMaxUsers;
 
 static char PromptType;
@@ -253,13 +265,18 @@ static int _dowriteall (char *str);
 void variable_expansion (struct mbuf ** bp);
 
 #ifdef UNIX
-#define VALIDOPTS "A:a:B:D:d:Ef:g:k:l:mno:P:r:S:s:T:tU:Vv?"
+# ifdef PATCURSES
+#  define VALIDOPTS "A:a:B:D:d:Ef:g:k:l:mno:P:r:S:s:T:tU:u:Vv?w:x:y:z:"
+# else
+#  define VALIDOPTS "A:a:B:D:d:Ef:g:k:l:mno:P:r:S:s:T:tU:u:Vv?"
+# endif
 #endif
+
 #ifdef MSDOS
-#define VALIDOPTS "A:a:B:D:d:Eef:g:h:k:mno:P:r:s:U:Vv?"
+#define VALIDOPTS "A:a:B:D:d:Eef:g:h:k:mno:P:r:s:U:u:Vv?"
 #endif
 #ifdef TNOS68K
-#define VALIDOPTS "A:a:B:cD:d:Ef:g:k:mno:P:r:s:U:Vv?"
+#define VALIDOPTS "A:a:B:cD:d:Ef:g:k:mno:P:r:s:U:u:Vv?"
 #endif
 
 
@@ -512,10 +529,42 @@ int32 cmdcounter = 0;
 				break;
 #endif
 
+#ifdef AXUDP
+			case 'u':	/* number of axudp interfaces */
+				AXUDPlinks = atoi (optarg);
+				break;
+#endif
+
 			case 'v':
 				Verbose = 1;
 				break;
 
+#if defined(UNIX) && defined(PATCURSES)	/* _ve1ttl - w, x, y, z */
+			case 'w':
+				i = getcolor (optarg);
+				if (i != -1)
+					STATback = i;
+				break;
+
+			case 'x':
+				i = getcolor (optarg);
+				if (i != -1)
+					STATfore = i;
+				break;
+
+			case 'y':
+				i = getcolor (optarg);
+				if (i != -1)
+					SPLITback = i;
+				break;
+
+			case 'z':
+				i = getcolor (optarg);
+				if (i != -1)
+					SPLITfore = i;
+				break;
+#endif
+
 			default:
 				break;
 		}
@@ -548,6 +597,9 @@ int32 cmdcounter = 0;
 #endif
 #ifdef AXIP
 	axipaddr = calloc ((unsigned) AXIPlinks, sizeof (int32));
+#endif
+#ifdef AXUDP
+	axudpcfg = calloc ((unsigned) AXUDPlinks, sizeof (AXUDPCFG));
 #endif
 	Mbox = (struct mbx **) calloc ((unsigned) NUMMBX, sizeof (struct mbx *));
 
@@ -2409,6 +2461,9 @@ char buf[80];
 #ifdef AXIP
 	tprintf (", AXIP interfaces = %-d", AXIPlinks);
 #endif
+#ifdef AXUDP
+	tprintf (", AXUDP interfaces = %-d", AXUDPlinks);
+#endif
 #ifdef NETROM
 	tprintf (", NETROM circuits = %-d", NR4MAXCIRC);
 #endif
@@ -2461,7 +2516,7 @@ domotd (int argc, char *argv[], void *p OPTIONAL)
 
 
 /* Command history, see also pc.c - WG7J */
-void
+static void
 logcmd (char *cmd)
 {
 struct hist *new;
