@@ -8,6 +8,8 @@
 #define ALLSESSIONS_VAL		0x80
 #define ALTERBID_OFF		4
 #define ALTERBID_VAL		0x04
+#define APRSD_OFF		10
+#define APRSD_VAL		0x80
 #define ARCNET_OFF		13
 #define ARCNET_VAL		0x08
 #define ASKHOME_OFF		4
@@ -22,6 +24,8 @@
 #define AXBCSTR_VAL		0x20
 #define AXIP_OFF		10
 #define AXIP_VAL		0x01
+#define AXUDP_OFF		18
+#define AXUDP_VAL		0x08
 #define AXUI_OFF		10
 #define AXUI_VAL		0x10
 #define BBSEXPORT_OFF		5
@@ -146,6 +150,8 @@
 #define NODECALL_VAL		0x04
 #define PACKET_OFF		14
 #define PACKET_VAL		0x40
+#define PATCURSES_OFF   	18
+#define PATCURSES_VAL   	0x10
 #define PC100_OFF		14
 #define PC100_VAL		0x20
 #define PC_EC_OFF		13
@@ -242,6 +248,8 @@
 #define STATS_USE_VAL		0x40
 #define STRICT_CALL_OFF		16
 #define STRICT_CALL_VAL		0x02
+#define STRICT_AX25CALL_OFF 	18
+#define STRICT_AX25CALL_VAL 	0x40
 #define STRICT_HTTPCALL_OFF	1
 #define STRICT_HTTPCALL_VAL	0x20
 #define TCPACCESS_OFF		7
@@ -266,6 +274,8 @@
 #define TUTOR_VAL		0x10
 #define UDPACCESS_OFF		17
 #define UDPACCESS_VAL		0x01
+#define UKIP_OFF    		18
+#define UKIP_VAL		0x20
 #define UNIX_SOCKETS_OFF	15
 #define UNIX_SOCKETS_VAL	0x20
 #define USEPOP3_OFF		7
@@ -288,11 +298,7 @@
 #define XSERVER_VAL		0x04
 
 
-#define UNUSED1_OFF		10
-#define UNUSED1_VAL		0x80
-
-
 #define MAPLENGTH 19
 
 
-/* next to be assigned, offset 18, value 0x40 */
+/* next to be assigned, offset 18, value 0x04 */
