@@ -2,7 +2,7 @@
 
 set NOSDIR "/nos"
 
-set RELEASE "2.30"
+set RELEASE "2.40"
 set TAB1 16
 set TAB2 8
 set AUTONOSDIR 0
@@ -218,6 +218,21 @@ if [file exists nosdir]	{
 	set AUTONOSDIR 1
 }
 
+if {$AUTOMATIC == 0 && [file exists $NOSDIR/etc/config.cfg] } {
+	set prompt "Use previous configuration from $NOSDIR/etc/config.cfg (Y/n) ?"
+	if {[info tclversion] > "7.4"} {
+		puts "$prompt"
+	} else {
+		puts -nonewline "$prompt"
+	}
+	set ans [gets stdin]
+	if {$ans == "y" || $ans == "Y" || $ans == ""} {
+		set AUTOMATIC 1
+		set AUTOCONFIG $NOSDIR/etc/config.cfg
+		puts "Autoconfig using: $AUTOCONFIG"
+	}
+}
+
 if {$AUTONOSDIR != 1}	{
 	getdir
 }
@@ -281,6 +296,6 @@ if {[info exists ISUNIX] == 1 && $ISUNIX == "y"} {
 }
 
 puts " "
-puts "The configuration is complete!"
+puts "The building of config.h is complete!"
 puts "\n"
 exit
