@@ -103,8 +103,10 @@ struct Servers {
 	char		*name;
 	uint32		 dest;
 	char		*newsgroups;   	/* list of newsgroups */
-	int		 lowtime;            /* for connect window */
+	int		 lowtime;       /* for connect window */
 	int		 hightime;
+        int              ihave;         /* Use 'ihave' pusher */
+        int              mode_reader;   /* Send 'MODE READER' when connecting */
 	struct Servers	*next;
 };
 #define NULLSERVER (struct Servers *)0
@@ -121,3 +123,4 @@ int donntp 	(int argc, char *argv[], void *p);
 int nnGpost	(FILE *data, const char *from, struct list *le);
 
 #endif /* _NNTP_H */
+
