@@ -15,7 +15,7 @@
 #include "trace.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: nr3.c,v 1.21 1997/09/07 21:18:28 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: nr3.c,v 1.22 2000/05/09 16:48:27 brian Exp $";
 #endif
 
 /* IF the following is defined,
@@ -29,7 +29,6 @@ static char rcsid[] OPTIONAL = "$Id: nr3.c,v 1.21 1997/09/07 21:18:28 root Exp r
 static int accept_bc (char *addr, struct iface * ifp);
 struct nr_bind *find_best (struct nr_bind * list, unsigned obso);
 static struct nr_bind *find_binding (struct nr_bind * list, struct nrnbr_tab * neighbor);
-struct nrnbr_tab *find_nrnbr (char *, struct iface *);
 void nrresetlinks (struct nrroute_tab * rp);	/* s/b in a header file */
 static struct nrnf_tab *find_nrnf (char *, struct iface *);
 static struct nr_bind *find_worst (struct nr_bind * list);
@@ -330,6 +329,9 @@ struct iface *iface;
 		free_p (bp);
 		return;
 	}
+
+	np->tries ++;
+   
 	(void) send_ax25 (axp, pbp, -1);	/* pass it off to ax25 code */
 }
 
