@@ -19,7 +19,7 @@
 #endif
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: nrcmd.c,v 1.19 1997/06/28 16:46:13 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: nrcmd.c,v 1.24 2001/05/06 16:32:58 brian Exp $";
 #endif
 
 /*lint -esym(534,pax25) */
@@ -203,7 +203,7 @@ char *cp, *temp;
 				if (!Nr_hidden && *rp->alias == '#')
 					continue;
 				if (Nr_sorttype) {
-					strcpy (buf, rp->alias);
+					strncpy (buf, rp->alias, 17);
 					/* remove trailing spaces */
 					if ((cp = strchr (buf, ' ')) == NULLCHAR)
 						cp = &buf[strlen (buf)];
@@ -300,7 +300,7 @@ int i, j, k, flow_tmp;
 					np = bp->via;
 					if (Nr_sorttype) {
 
-						strcpy (buf, rp->alias);
+						strncpy (buf, rp->alias, 17);
 						if ((cp = strchr (buf, ' ')) == NULLCHAR)
 							cp = &buf[strlen (buf)];
 						if (cp != buf)
@@ -384,7 +384,7 @@ int16 rhash;
 		return 0;
 	}
 	/*copy the real alias*/
-	strcpy (buf, rp->alias);
+	strncpy (buf, rp->alias, AXALEN);
 	if ((cp = strchr (buf, ' ')) != NULLCHAR)
 		*cp = '\0';
 
@@ -433,6 +433,7 @@ int justused;
 char tmp[AXBUF];
 char alias[AXALEN];
 char *cp;
+int percentage = 0;
 int quality = 0;
 int obsocnt = 0;
 
@@ -444,7 +445,7 @@ int obsocnt = 0;
 				continue;
 			 */
 			if (printheader) {
-				tputs ("Routes :\n   Neighbour       Port  PQual Obsocnt Dest\n");
+				tputs ("Routes :\n   Neighbour       Port  PQual Obsocnt Dest  Tries  Retries Perc\n");
 				printheader = 0;
 			}
 			/* has this one been used recently ? */
@@ -475,13 +476,18 @@ int obsocnt = 0;
 					quality = obsocnt = 0;
 			} else
 				strcpy (alias, "##temp");
+		        if (np->tries)  /* Filched from JNOS */
+				    percentage = ((np->tries *100L) / (np->tries + np->retries));
+		        else
+				    percentage = 0;
 
 			/* print it all out */
-			tprintf ("%s %6s:%-9s  %-5s %4d     %1d    %3d\n",
+			tprintf ("%s %6s:%-9s  %-5s %4d     %1d    %3d  %-5u  %-5u   %2d %%\n",
 				 (justused) ? ">" : " ",
 				 alias, pax25 (tmp, np->call),
 				 np->iface->name,
-				 quality, obsocnt, np->refcnt);
+				 quality, obsocnt, np->refcnt,
+				 np->tries, np->retries, percentage);
 		}
 	if (!printheader)
 		tputc ('\n');
@@ -567,6 +573,12 @@ int i, mtu;
 		tprintf ("Interface %s is not NETROM compatible\n", argv[1]);
 		return 1;
 	}
+
+	if (!strcasecmp (argv[2], "off"))	{
+		ifp->flags &= ~IS_NR_IFACE;
+		return 0;
+	}
+
 	/* activate the interface */
 	ifp->flags |= IS_NR_IFACE;
 
@@ -736,7 +748,7 @@ donodetimer (int argc, char *argv[], void *p OPTIONAL)
 	Nodetimer.func = (void (*)(void *)) donodetick;	/* what to call on timeout */
 	Nodetimer.arg = NULLCHAR;	/* dummy value */
 	set_timer (&Nodetimer, atoi (argv[1]) * 1000L);	/* set timer duration */
-	start_timer (&Nodetimer);	/* and fire it up */
+	start_detached_timer (&Nodetimer);	/* and fire it up */
 	return 0;
 }
 
@@ -766,7 +778,7 @@ struct iface *ifp;
 	}
 
 	/* Restart timer */
-	start_timer (&Nodetimer);
+	start_detached_timer (&Nodetimer);
 }
 
 
@@ -784,7 +796,7 @@ doobsotimer (int argc, char *argv[], void *p OPTIONAL)
 	Obsotimer.func = (void (*)(void *)) doobsotick;	/* what to call on timeout */
 	Obsotimer.arg = NULLCHAR;	/* dummy value */
 	set_timer (&Obsotimer, atoi (argv[1]) * 1000L);	/* set timer duration */
-	start_timer (&Obsotimer);	/* and fire it up */
+	start_detached_timer (&Obsotimer);	/* and fire it up */
 	return 0;
 }
 
@@ -848,7 +860,7 @@ int i;
 		}
 	}
 
-	start_timer (&Obsotimer);
+	start_detached_timer (&Obsotimer);
 }
 
 
@@ -1380,7 +1392,7 @@ unsigned val;
 
 
 /* Fixed and now functional, 920317 WG7J */
-int
+static int
 donrload (int argc OPTIONAL, char *argv[] OPTIONAL, void *p OPTIONAL)
 {
 char buff[255];
@@ -1407,18 +1419,18 @@ char destneighbor[AXALEN];
 		return 1;
 	}
 	if (fgets (buff, sizeof (buff), fn) == NULLCHAR) {	/* read the timestamp */
-		fclose (fn);
+		(void) fclose (fn);
 		return 1;
 	}
 	if ((strncmp (buff, "time = ", 7)) != 0) {
 		tputs("Wrong node file content\n");
-		fclose (fn);
+		(void) fclose (fn);
 		return 1;
 	}
 	(void) time (&now);
 	sscanf (buff, "time =%ld", &prev);
 	if (prev >= now) {
-		fclose (fn);
+		(void) fclose (fn);
 		return 1;
 	}
 #ifdef notdef
@@ -1471,12 +1483,12 @@ char destneighbor[AXALEN];
 		(void) nr_routeadd (destalias, destcall, ifp, (unsigned) quality, destneighbor, \
 			     (unsigned) permanent, (unsigned) record);
 	}
-	fclose (fn);
+	(void) fclose (fn);
 	return 0;
 }
 
 
-int
+static int
 donrsave (int argc OPTIONAL, char *argv[] OPTIONAL, void *p OPTIONAL)
 {
 register struct nrroute_tab *rp;
@@ -1497,7 +1509,7 @@ time_t now;
 	fprintf (fn, "time = %ld\n", now);
 	for (i = 0; i < NRNUMCHAINS; i++) {
 		for (rp = Nrroute_tab[i]; rp != NULLNRRTAB; rp = rp->next) {
-			strcpy (buf, rp->alias);
+			strncpy (buf, rp->alias, 16);
 			/* remove trailing spaces */
 			if ((cp = strchr (buf, ' ')) == NULLCHAR)
 				cp = &buf[strlen (buf)];
@@ -1517,7 +1529,7 @@ time_t now;
 			}
 		}
 	}
-	fclose (fn);
+	(void) fclose (fn);
 	return 0;
 }
 
