@@ -37,4 +37,30 @@ extern unsigned _stklen;
 void clrscr(), free();
 char *malloc();
 char *strchr(), *strrchr(), *strstr(), *strpbrk();
+
+/* Template for contents of jmp_buf for 68302 */
+struct env {
+	unsigned	_pc;
+	unsigned	_d0;
+	unsigned	_d1;
+	unsigned	_d2;
+	unsigned	_d3;
+	unsigned	_d4;
+	unsigned	_d5;
+	unsigned	_d6;
+	unsigned	_d7;
+	unsigned	_a0;
+	unsigned	_a1;
+	unsigned	_a2;
+	unsigned	_a3;
+	unsigned	_a4;
+	unsigned	_a5;
+	unsigned	_a6;
+	unsigned	_a7;
+	unsigned	_xtra;
+};
+
+#define TNOS_SP(p) (((struct env *)p->env)->_a7)
+#define TNOS_PC(p) (((struct env *)p->env)->_pc)
+
 #endif	/* _TNOS_68K_H */
