@@ -46,7 +46,7 @@ static int poplzw = TRUE;	/* no way yet to reset this */
 
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: pop3serv.c,v 1.22 1997/05/24 12:55:33 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: pop3serv.c,v 1.25 1997/09/07 21:18:28 root Exp $";
 #endif
 
 
@@ -114,7 +114,6 @@ static char	count_rsp[]		= "+OK you have %d messages\n",
 		signoff_msg[]		= "+OK Bye, bye-bye, bye now, goodbye\n";
 
 
-void rrip (register char *s);
 static struct pop_scb *create_scb (void);
 static void delete_scb (struct pop_scb *scb);
 static void popserv (int s, void *unused, void *p);
@@ -271,7 +270,7 @@ delete_scb (register struct pop_scb *scb)
 	if (scb == NULLSCB)
 		return;
 	if (scb->wf != NULL)
-		fclose (scb->wf);
+		(void) fclose (scb->wf);
 	if (scb->msg != NULL)
 		delete_msglist (scb->msg);
 	if (scb->challenge != NULL)
@@ -282,26 +281,6 @@ delete_scb (register struct pop_scb *scb)
 
 
 
-/* replace terminating end of line marker(s) (\r and \n) with null,
-                        and change . to .. */
-void
-rrip (register char *s)
-{
-register char *cp;
-
-	if ((cp = strchr (s, '\r')) != NULLCHAR)
-		*cp = '\0';
-#ifndef TNOS_68K
-	if ((cp = strchr (s, '\n')) != NULLCHAR)
-#else
-	if ((cp = strchr (s, '\l')) != NULLCHAR)
-#endif
-		*cp = '\0';
-}
-
-
-
-
 /* --------------------- start of POP server code ------------------------ */
 
 
@@ -356,7 +335,7 @@ int lzwmode, lzwbits;
 
 		case AUTH:
 			if (strncmp (scb->buf, user_cmd, strlen (user_cmd)) == 0) {
-				sscanf (scb->buf, "USER %s", scb->username);
+				strncpy (scb->username, &scb->buf[strlen(user_cmd)], 64);
 				(void) usputs (scb->socket, user_rsp);
 
 			} else if (strncmp (scb->buf, pass_cmd, strlen (pass_cmd)) == 0) {
@@ -364,7 +343,7 @@ int lzwmode, lzwbits;
 					state_error (scb, "Access DENIED!!");
 					return;
 				}
-				sscanf (scb->buf, "PASS %s", password);
+				strncpy (password, &scb->buf[strlen(pass_cmd)], 40);
 
 				if (!poplogin (scb->username, password)) {
 					log (scb->socket, "POP3 access DENIED to %s", scb->username);
@@ -378,7 +357,7 @@ int lzwmode, lzwbits;
 					state_error (scb, "Access DENIED!!");
 					return;
 				}
-				sscanf (scb->buf, "APOP %s %s", scb->username, password);
+				sscanf (scb->buf, "APOP %64s %40s", scb->username, password);
 
 				if (!apoplogin (scb->username, scb->challenge, password)) {
 					log (scb->socket, "POP3 apop access DENIED to %s", scb->username);
@@ -468,7 +447,7 @@ fatal_error (struct pop_scb *scb, const char *msg)
 static void
 close_folder (struct pop_scb *scb)
 {
-char folder_pathname[64];
+char folder_pathname[128];
 char line[TLINELEN + 1];
 FILE *fd;
 int deleted = FALSE;
@@ -486,7 +465,7 @@ struct let lt;
 	if (!scb->folder_modified) {
 		/* no need to re-write the folder if we have not modified it */
 
-		fclose (scb->wf);
+		(void) fclose (scb->wf);
 		scb->wf = NULL;
 
 		delete_msglist (scb->msg);
@@ -508,7 +487,7 @@ struct let lt;
 			fputs (line, scb->wf);
 		}
 
-		fclose (fd);
+		(void) fclose (fd);
 	}
 	/* now create the updated mail folder */
 
@@ -569,11 +548,11 @@ struct let lt;
 	if (deleted == FALSE)
 		updateCtl (scb->username, &lt);
 
-	fclose (fd);
+	(void) fclose (fd);
 	rmlock (Mailspool, scb->username);
 	if (fsize (folder_pathname) == 0L)	/* N1BEE */
 		unlink (folder_pathname);
-	fclose (scb->wf);
+	(void) fclose (scb->wf);
 	scb->wf = NULL;
 	delete_msglist (scb->msg);
 	scb->msg = NULL;
@@ -610,7 +589,7 @@ struct pop_msg *msg;
 		state_error (scb, "Unable to create work folder");
 		return;
 	}
-	scb->msg = calloc (sizeof (struct pop_msg), 1);	/* create first element */
+	scb->msg = callocw (sizeof (struct pop_msg), 1);	/* create first element */
 
 	if (scb->msg == NULL) {
 		fatal_error (scb, "Unable to create pointer list");
@@ -630,7 +609,7 @@ struct pop_msg *msg;
 		if (isSOM (line)) {
 			kwait (NULL);	/* be nice to the others */
 			scb->folder_len++;
-			msg->next = calloc (sizeof (struct pop_msg), 1);
+			msg->next = callocw (sizeof (struct pop_msg), 1);
 
 			if (msg->next == NULL) {
 				fatal_error (scb, "Unable to create pointer list");
@@ -645,13 +624,13 @@ struct pop_msg *msg;
 			/* now put  the line in the work file */
 		}
 		fputs (line, scb->wf);
-		rrip (line);
+		rip (line);
 		if (*line == '.')
 			msg->len++;
 		msg->len += (long) (strlen (line) + 2);	/* Add msg len count */
 	}
 
-	fclose (fd);
+	(void) fclose (fd);
 	scb->high_num = 0;	/* reset high read */
 
 	usprintf (scb->socket, count_rsp, scb->folder_len);
@@ -750,7 +729,7 @@ int first_line = TRUE;
 
 	while (!feof (scb->wf) && (cnt > 0)) {
 		(void) fgets (line, TLINELEN, scb->wf);
-		rrip (line);
+		rip (line);
 		if (first_line) {
 			first_line = FALSE;
 			if (isSOM (line)) {
@@ -849,7 +828,7 @@ long total = 0;
 	(void) usputs (scb->socket, noop_rsp);	/* Give OK */
 	do {
 		(void) fgets (line, TLINELEN, scb->wf);
-		rrip (line);
+		rip (line);
 		if (*line == '.') {
 			(void) usputc (scb->socket, '.');
 			total--;
@@ -859,7 +838,7 @@ long total = 0;
 	} while (*line != '\0' && total > 0);
 	for ( ; total > 0 && lines; --lines) {
 		(void) fgets (line, TLINELEN, scb->wf);
-		rrip (line);
+		rip (line);
 		if (*line == '.') {
 			(void) usputc (scb->socket, '.');
 			total--;
@@ -904,10 +883,10 @@ FILE *fp;
 	if (feof (fp)) {
 		/* User name not found in file */
 
-		fclose (fp);
+		(void) fclose (fp);
 		return (FALSE);
 	}
-	fclose (fp);
+	(void) fclose (fp);
 
 	if (cp == NULLCHAR || (cp1 = strchr (cp, ':')) == NULLCHAR)
 		return (FALSE);
@@ -954,10 +933,10 @@ MD5_CTX mdContext;
 	if (feof (fp)) {
 		/* User name not found in file */
 
-		fclose (fp);
+		(void) fclose (fp);
 		return (FALSE);
 	}
-	fclose (fp);
+	(void) fclose (fp);
 
 	if (cp == NULLCHAR || (cp1 = strchr (cp, ':')) == NULLCHAR)
 		return (FALSE);
