@@ -16,7 +16,7 @@
 #include "ftpserv.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: reqsvr.c,v 1.24 1997/05/24 12:54:48 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: reqsvr.c,v 1.26 1997/08/19 01:19:22 root Exp $";
 #endif
 
 extern int mailuser (FILE *data,const char *from,const char *to,const char *origto);
@@ -56,7 +56,7 @@ FILE *fp;
 		fputs (str, fp);
 		rewind (fp);
 		(void) rdaemon (fp, replyto, from, to, msg, msgtype, mode);
-		fclose (fp);
+		(void) fclose (fp);
 	}
 }
 
@@ -130,7 +130,7 @@ long mid;
 	(void) mailuser(tfile, (from) ? from : buf, to, orgto);
 	free (to);
 	free (orgto);
-	fclose(tfile);
+	(void) fclose(tfile);
 	kwait (NULL);
 	return 0;
 }
@@ -163,9 +163,10 @@ char buf[LINELEN];
 			return 0;
 		}
 		(void) rdaemon (fp, NULLCHAR, from, to, subj, 'P', 0);
-		fclose (fp);
+		(void) fclose (fp);
 	} else 		/* string data given */
 		rdaemon_str (data, NULLCHAR, from, to, subj, 'P', 0);
+	smtptick (NULL);	/* wake SMTP to send that mail */
 	return 0;
 }
 
@@ -373,7 +374,7 @@ struct mbx *mb;
 		time_t t;
 		(void) time(&t);
 		fprintf (out, "Received from %s (%s) on %s", realfrom, subject, ptime(&t));
-		fclose (out);
+		(void) fclose (out);
 	}
 	if (!*subject)
 		return 0;	/* we are konfuzd! No subject!?!? */
@@ -599,7 +600,7 @@ ioerror:						sprintf (buf, "IO Error %s", subject);
 							kwait (NULL);
 							fputs(buf,out);
 						}
-						fclose (out);
+						(void) fclose (out);
 						cp = strrchr (file, '/');
 						if (cp)
 							*cp++ = 0;
@@ -639,10 +640,10 @@ ioerror:						sprintf (buf, "IO Error %s", subject);
 								}
 							}
 							if (out2 != NULLFILE)
-								fclose (out2);
+								(void) fclose (out2);
 						}
 complete:					if (out != NULLFILE)	{
-							fclose (out);
+							(void) fclose (out);
 							out = NULLFILE;
 						}
 						if (!strnicmp (subject, "uploadblind", 11) || !strnicmp (subject, "ub", 2))
@@ -656,7 +657,7 @@ okay:						sprintf (buf, "Accepted %s", subject);
 							rewind (out);
 						(void) rdaemon (out, NULLCHAR, NULLCHAR, realfrom, buf, 'P', 0);
 						if (out != NULLFILE)
-							fclose (out);
+							(void) fclose (out);
 						break;
 					default:
 						break;
