@@ -38,7 +38,7 @@
 #include "rip.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: rip.c,v 1.25 1997/09/07 21:18:28 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: rip.c,v 1.27 2001/05/06 16:32:58 brian Exp $";
 #endif
 
 struct rip_stat Rip_stat = {{{0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}}, 0, 0, 0, 0, 0, 0};
@@ -111,10 +111,10 @@ struct route *rp;
 struct socket lsock, fsock;
 struct iface *iface;
 
-	if (version == RIP_VERSION_98) { /* Fiddling to make RIP98 like latest official +1 */
+	if (version == RIP_VERSION_98)  /* Fiddling to make RIP98 like latest official +1 */
 		version = RIP_VERSION_X;
+	if (version == RIP_VERSION_X)
 		riplen = RIP98_ENTRY;
-	}
    
 	if ((rp = rt_lookup (dest)) == NULLROUTE) {
 		rip_trace (1, "No route to [%s] exists, cannot send", inet_ntoa (dest));
@@ -154,7 +154,7 @@ struct iface *iface;
 	}
 
 	/* Emit route to ourselves, if requested */
-	if (flags & RIP_US) {
+	if ((flags & RIP_US) && !trig) {        /* Except on a trigger - G4HIP */
 		switch (version) {
 			case RIP_VERSION_1:
 				cp = putentry (cp, RIP_AF_INET, 0, iface->addr, 0, 0, 1);
@@ -629,7 +629,7 @@ struct rip_list *rl;
 	   
 		case RIP_VERSION_X:
 	                
-			if (header.rip_cmd != RIPCMD_RESPONSE) {
+			if ((header.rip_cmd != RIPCMD_RESPONSE) && (header.rip_cmd != RIPCMD_REQUEST)) {
 				rip_trace (1, "RIP-98 invalid header received from [%s]\n", inet_ntoa (fsock.address));
 				Rip_stat.vdata[RIP_VERSION_X].unknown++;
 				free_p (bp);
@@ -714,9 +714,12 @@ struct rip_list *rl;
 			 * complete implementation that checks for non-global requests
 			 */
 
+		    if ((rp = rt_lookup (fsock.address)) == NULLROUTE) { /* G4HIP */
+			    rip_trace (2, "RIPCMD_REQUEST - no route to [%s]", inet_ntoa (fsock.address));
+			    break;
+		    }
 			if (header.rip_vers > RIP_VERSION_1) {
 				/* RIP-2, let's see if we know something about this guy */
-				rp = rt_lookup (fsock.address);
 				for (rl = Rip_list; rl != NULLRL; rl = rl->next)
 					if ((rl->dest == rp->target) && (rl->domain == header.rip_domain))
 						break;
@@ -980,7 +983,7 @@ register struct rip_list *rl;
 	fsock.port = RIP_PORT;
 
 	/* Send out one RIP Request packet as a broadcast to 'dest'  */
-	if ((bp = alloc_mbuf (RIP_HEADER + RIP_ENTRY)) == NULLBUF)
+	if ((bp = alloc_mbuf (RIP_HEADER + (2*RIP_ENTRY))) == NULLBUF)
 		return -1;
 
 	/* Check to see if we already know something about who we're   */
@@ -1005,6 +1008,10 @@ register struct rip_list *rl;
 		Rip_stat.vdata[version].output++;
 	}
 
+        if (version == RIP_VERSION_98 || ((rl != NULLRL) && (rl->rip_version == RIP_VERSION_98))) {
+			cp = put98entry(cp, 0, 0, RIP_METRIC_UNREACHABLE);
+	        bp->cnt = RIP_HEADER + RIP98_ENTRY;
+	} else
 	cp = putentry (cp, 0, 0, 0L, 0L, 0L, RIP_METRIC_UNREACHABLE);
 	(void) send_udp (&lsock, &fsock, 0, 0, bp, bp->cnt, 0, 0);
 	return 0;
@@ -1086,7 +1093,7 @@ unsigned char *cp = (unsigned char *) cptr;
 
 
 /* Check the authentication of RIP-II packets */
-int
+static int
 check_authentication (struct rip_auth *auth, struct mbuf **bpp OPTIONAL, struct rip_head *header,
 	uint32 srcaddr, char const *ifcname, struct rip_authenticate *entry)
 {
@@ -1174,7 +1181,7 @@ register struct route *rp = (struct route *) s;
 
 
 
-void
+static void
 pullheader (struct rip_head *ep, struct mbuf **bpp)
 {
 	ep->rip_cmd = uchar(pullchar (bpp));
@@ -1184,7 +1191,7 @@ pullheader (struct rip_head *ep, struct mbuf **bpp)
 
 
 
-void
+static void
 rip_trace (short level, char const *errstr,...)
 {
 	if ((int16) level <= Rip_trace) {
