@@ -23,7 +23,7 @@
 #include "sessmgr.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: sessmgr.c,v 1.19 1997/06/01 22:10:46 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: sessmgr.c,v 1.21 2001/05/06 16:32:58 brian Exp $";
 #endif
 
 static int dosmstatus (int, char **, void *);
@@ -202,7 +202,7 @@ dosessmgr (int argc, char **argv, void *p)
 
 
 
-int
+static int
 dosmstatus (int argc OPTIONAL, char **argv OPTIONAL, void *p OPTIONAL)
 {
 struct screen *sp;
@@ -240,7 +240,7 @@ int s;
 
 
 
-int
+static int
 dosmdefault (int argc, char **argv, void *p OPTIONAL)
 {
 char const *cp;
@@ -273,7 +273,7 @@ char const *cp;
 
 
 
-int
+static int
 dosmcreate (int argc, char **argv, void *p)
 {
 int rc;
@@ -295,7 +295,7 @@ int rc;
 
 
 
-int
+static int
 dosmoptions (int argc, char **argv, void *p OPTIONAL)
 {
 struct screen *sp;
@@ -428,7 +428,7 @@ int susp;
 
 
 
-int
+static int
 dosmreparent (int argc, char **argv, void *p OPTIONAL)
 {
 struct sessmgr_sw *old;
@@ -896,7 +896,7 @@ int i, c, statsize;
 				}
 				statsize = 0;
 				if (sp->screen->statline)
-					statsize = ((sp == Command) ? 2 : 1);
+					statsize = ((sp == Command) ? getStatlines() : 1);
 
 				if (sp->flowmode && c == '\n' && sp->row > 0 && --sp->row == statsize) {
 					scputs (sp, "--More--");
