@@ -32,7 +32,7 @@ void mail2news (FILE *fp, const char *from, const char *to, const char *area);
 #include "stats.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: smtpserv.c,v 1.42 1997/08/19 01:19:22 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: smtpserv.c,v 1.45 2000/06/28 22:31:36 gareth Exp $";
 #endif
 
 const char *Days[7] = { "Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat" };
@@ -90,6 +90,9 @@ int makeBBSbid (char *bid, int bidlen, char *line);
 void updateFwd (char *who, char *area, long bid, long size);
 static int isanIPhost (char *str);
 static struct list *expandgroup (struct list ** head, const char *user, const char *orig);
+int relaycheck (struct smtpsv * mp, uint32 addr, char *orig);
+uint32 getaddr (struct smtpsv * mp);
+
 
 #ifdef TRANSLATE
 char *translate (register char *searchfor, int *didwe);
@@ -99,6 +102,10 @@ char *translate (register char *searchfor, int *didwe);
 extern void importcmd (int mode, char *bbsname);
 #endif
 
+#ifdef HOLDMODS
+int holdjob (FILE *dfile, char *host, struct list *to, const char *from);
+#endif
+
 /* Command table */
 static const char *commands[] =
 {
@@ -163,6 +170,7 @@ static char Unknown[] = "550 <%s> address unknown\n";
 static char Refused[] = "550 <%s> address refused\n";
 static char Noalias[] = "550 No alias for <%s>\n";
 static char ListNoUser[] = "550 That is a mailing list, not a user\n";
+static char Relaydenied[] = "550 Relaying denied\n";
 static char VrfyName[] = "250 <%s@%s>\n";
 static char DAEMONSTR[] = "%sMAILER-DAEMON@%s (Mail Delivery Subsystem)\n";
 
@@ -185,6 +193,7 @@ extern char *ExpireArea;
 extern int Smtpslzw;
 extern int Smtpquiet;
 extern int BIDuknos;
+extern int SMTPnorelay;
 
 #ifdef	MSDOS
 /* Valid characters in a DOS filename matrix */
@@ -258,6 +267,7 @@ int cnt;
 char address_type;
 char *orig;
 int talkingtoself = 0;
+uint32 addr = 0;
 #ifdef	LZW
 int lzwbits, lzwmode;
 #endif
@@ -334,8 +344,13 @@ loop:
 			free (mp->system);
 			mp->system = strdup (arg);
 			usprintf (mp->s, Ourname, Hostname);
+#if 1
+		    if ((addr = getaddr(mp)) == Ip_addr)   /* Check we really are talking to self */
+			    talkingtoself = 1;
+#else
 			if (!strcmp (arg, Hostname))
 				talkingtoself = 1;
+#endif
 			break;
 		case NOOP_CMD:
 			usprintf (mp->s, Ok);
@@ -392,9 +407,19 @@ loop:
 			/* if a local address check for an alias */
 			if (address_type == LOCAL)
 				(void) expandalias (&mp->to, cp, orig);
-			else
-				/* a remote address is added to the list */
-				(void) addlist (&mp->to, cp, address_type, orig);
+			else {			
+				/* This message is not for local delivery
+				 * Check to see if we can relay it */
+				if  (!SMTPnorelay || talkingtoself || relaycheck(mp, addr, cp))	
+					/* a remote address is added to the list */
+					(void) addlist (&mp->to, cp, address_type, orig);
+				else {
+					usprintf (mp->s, Relaydenied);
+					log (mp->s, "SMTP relay denied. Msg from: %s to: %s rewritten as: %s", mp->from, orig, cp);
+					free (orig);
+					break;
+				}
+			}
 
 			usprintf (mp->s, Ok);
 			free (orig);
@@ -569,7 +594,7 @@ int firstfrom = 0;
 	(void) time (&t);
 	fprintf (mp->data, Hdrs[RECEIVED]);
 	if (mp->system != NULLCHAR)
-		fprintf (mp->data, "from %s ", mp->system);
+		fprintf (mp->data, "from %s [%s] ", mp->system, inet_ntoa (getaddr(mp)));
 #ifdef MBFWD
 	fprintf (mp->data, "by %s (%s) with SMTP\n\tid AA%ld ; %s",
 	       Hostname, (Mbfwdinfo != NULLCHAR) ? Mbfwdinfo : shortversion,
@@ -816,6 +841,7 @@ int k, Holdit = 0;
 	for (k = 0; k < 100 && badwords[k]; k++) {
 		if (strstr (badbuf, badwords[k])) {
 			Holdit = 1;
+			log (-1, "Holdscan found: %s in: %s", badwords[k], badbuf);
 			break;
 		}
 	}
@@ -893,24 +919,9 @@ char rejto[256];
 #if defined(REJECT) || defined(NNTPS)
 	rejto[0] = 0;
 #endif
-#ifdef HOLDMODS
-	{
-		FILE *fpp;
 
-		theindex = 0;
-		if ((fpp = fopen (WordHoldFile, "r")) != NULLFILE) {
-			while (fgets (badbuf, sizeof (badbuf), fpp) != NULLCHAR) {
-				rip (badbuf);
-				(void) strlwr (badbuf);
-				badwords[theindex++] = strdup (badbuf);
-				if (theindex == 99)
-					break;
-			}
-			(void) fclose (fpp);
-		}
-		badwords[theindex] = NULLCHAR;
-		totalindex = theindex;
-	}
+#ifdef HOLDMODS
+	totalindex = load_badwords (badbuf, badwords, sizeof(badbuf));
 #endif
 	do {
 		qhost = NULLCHAR;
@@ -930,6 +941,13 @@ char rejto[256];
 			}
 		}
 		if (qhost != NULLCHAR) {
+#ifdef HOLDMODS
+			if ((Sholdscanall > 1) && (scan_message(data, badbuf, badwords))) {
+				rewind (data);
+				(void) rdaemon (data, NULLCHAR, NULLCHAR, NULLCHAR, "Message with naughty word in hqueue", 'P', 0);
+				return (holdjob (data, qhost, dlist, from));
+			}
+#endif	
 			rewind (data);
 			(void) queuejob (data, qhost, dlist, from);
 			del_list (dlist);
@@ -1029,11 +1047,12 @@ char rejto[256];
 
 		if (destarea != (char **) 0)
 			*destarea = NULLCHAR;
-		if ((realarea = rewrite_address ((!strnicmp (ap->orig, "cc:", 3)) ? &ap->orig[3] : ap->orig, 0)) == NULLCHAR)
+		if ((realarea = rewrite_address ((!strnicmp (ap->orig, "cc:", 3)) ? &ap->orig[3] : ap->orig, 0)) == NULLCHAR)	{
 			if (!strnicmp (ap->val, "cc:", 3))
 				realarea = strdup (&ap->val[3]);
 			else
 				realarea = strdup (ap->val);
+		}
 
 		kwait (NULL);
 		/* if mail file is busy save it in our smtp queue
@@ -1093,9 +1112,10 @@ char rejto[256];
 					kwait (NULL);
 #ifdef HOLDMODS
 					if (!Holdit) {
-						Holdit = holdscan (buf, badbuf, badwords);
+						if (strcmp (realarea, "sysop"))
+							Holdit = holdscan (buf, badbuf, badwords);
 						if (Holdit)
-							log (-1, "WordHold New mail for %s from <%s>\n", realarea, from);
+							log (-1, "WordHold 1 New mail for %s from <%s>\n", realarea, from);
 					}
 #endif
 
@@ -1271,9 +1291,10 @@ char rejto[256];
 					kwait (NULL);
 #ifdef HOLDMODS
 					if (!Holdit) {
-						Holdit = holdscan (buf, badbuf, badwords);
+						if (strcmp (realarea, "sysop"))
+							Holdit = holdscan (buf, badbuf, badwords);
 						if (Holdit)
-							log (-1, "WordHold New mail for %s from <%s>\n", realarea, from);
+							log (-1, "WordHold 2 New mail for %s from <%s>\n", realarea, from);
 					}
 #endif
 					fputs (buf, fp);
@@ -1308,6 +1329,8 @@ char rejto[256];
 						if ((fpp = fopen (UserHoldFile, "r")) != NULLFILE) {
 							while (fgets (buf, sizeof (buf), fpp) != NULLCHAR) {
 								rip (buf);
+								if (strlen (buf) < 3)
+									continue;
 								(void) strlwr (buf);
 								strncpy (badbuf, from, LINELEN);
 								(void) strlwr (badbuf);
@@ -1498,7 +1521,7 @@ ptime (time_t *t)
 		 Days[ltm->tm_wday],
 		 ltm->tm_mday,
 		 Months[ltm->tm_mon],
-		 ltm->tm_year,
+		 (ltm->tm_year % 100),
 		 ltm->tm_hour,
 		 ltm->tm_min,
 		 ltm->tm_sec,
@@ -1563,7 +1586,7 @@ FILE *sfile;
 int
 validate_address (const char *s)
 {
-char *cp;
+char *cp, *cp1;
 uint32 addr;
 
 	if (*s == '!') {
@@ -1578,6 +1601,13 @@ uint32 addr;
 	/* if address has @ in it then check dest address */
 	if ((cp = strrchr (s, '@')) != NULLCHAR) {
 		cp++;
+		/* If smtp norelay is on, check for more than one '@' character */
+		if (SMTPnorelay) {
+			cp1 = strchr (s, '@');
+			cp1 ++;
+			if (cp != cp1)
+				return BADADDR;
+		}
 		/* 1st check if it is our hostname.
 		* if not then check the hosts file and see if we can
 		* resolve the address to a known site or one of our aliases.
@@ -1679,8 +1709,12 @@ long totalcnt = 0;
 	for (ap = to; ap != NULLLIST; ap = ap->next) {
 		if (host == NULLCHAR)
 			fprintf (fp, "To: ");
-		else
-			smtplog ("queue job %s To: %s From: %s Size: %ld", prefix, ap->val, from, totalcnt);
+		else {
+			if (!strcmp (qdir, Holdqdir))
+				smtplog ("hqueue job %s To: %s From: %s Size: %ld", prefix, ap->val, from, totalcnt);
+			else
+				smtplog ("queue job %s To: %s From: %s Size: %ld", prefix, ap->val, from, totalcnt);
+		}
 		fprintf (fp, "%s\n", ap->val);
 	}
 	(void) fclose (fp);
@@ -1716,6 +1750,18 @@ const char *from
 	return (__queuejob (dfile, host, to, from, Mailqdir));
 }
 
+#ifdef HOLDMODS
+/* place a mail job in the hold queue */
+int
+holdjob (
+FILE *dfile,
+char *host,
+struct list *to,
+const char *from
+) {
+	return (__queuejob (dfile, host, to, from, Holdqdir));
+}
+#endif
 
 /* add an element to the front of the list pointed to by head
 ** return NULLLIST if out of memory.
@@ -2175,3 +2221,160 @@ int i, j;
 }
 
 #endif
+
+/* Following are 'smtp norelay' enhancments - G4HIP */
+
+/* Decide whether a message can be relayed - See RFC 2505 */
+int
+relaycheck (struct smtpsv * mp, uint32 addr, char *toaddr)
+{
+FILE *fp;
+char *cp, *cp1, *cp2;
+char buf[LINELEN];
+char toaddr1[LINELEN];
+int smaskbits, action = 0;
+uint32 checkaddr, addr1;
+	
+	/* Check out which callers are specifically mentioned */
+	
+	if ((fp = fopen (Mailrelay, READ_TEXT)) != NULLFILE) {
+		while (fgets (buf, sizeof (buf), fp) != NULLCHAR) {
+			rip (buf);
+			cp = skipwhite (buf);
+			if (*cp == '#' || !*cp)
+				continue;
+			if (*cp == '!') {
+				action = -1;
+				cp ++;
+			}
+			else
+				action = 1;
+			if (strcspn (cp, "0123456789./") == 0) { /* Dotted quad */
+				cp++;
+				cp = skipwhite (buf);
+				if ((cp1 = strchr (buf, '/')) != NULLCHAR) {
+					*cp1 = '\0';
+					cp1 ++;
+					smaskbits = atoi (cp1);
+				}
+				else
+					smaskbits = 32;
+				checkaddr = aton (cp);
+				addr1 = addr;
+				addr1 &= ~0L << (32-smaskbits);
+			
+				if ((addr1 == checkaddr) || smaskbits == 0) {
+					fclose (fp);
+					if (action == -1)
+						return 0;
+					else
+						return 1;
+				}
+			}
+		}
+		fclose (fp);
+}
+    /* Null 'Mail From:' commands are exploited by spammers   */
+#if 0
+	/* If the 'mail from' address is 'null' we must accept it */
+	if (strlen (mp->from) == 0)				
+		return 1;
+#endif
+	
+	/* If apparently from someone at our local domain we should accept it */
+	strcpy (buf, mp->from);
+	if ((cp = strrchr (buf, '@')) != NULLCHAR) {  /* This may need work later to   */
+		if (strcmp (cp, Hostname) == 0) /* encompass true 'local domain' */
+			return 1;
+	}
+	
+	/* Check the 'mailrelay' file to see if it is for a host we relay for */
+	strcpy (toaddr1, toaddr);	
+	if ((fp = fopen (Mailrelay, READ_TEXT)) != NULLFILE) {
+		while (fgets (buf, sizeof (buf), fp) != NULLCHAR) {
+			rip (buf);
+			cp = skipwhite (buf);
+			if (*cp == '#' || !*cp)
+				continue;
+
+			/* Is the mail from a user at host we relay for ? */
+			if ((cp1 = strrchr(mp->from, '@')) != NULLCHAR) {
+				if (wildmat (cp1, cp, NULLCHARP)) {
+					fclose(fp);
+					return 1;
+				}
+			}
+			
+			/* Is the mail to a user at a host we relay for ? */
+			if ((cp1 = strrchr(toaddr1, '@')) != NULLCHAR) {
+				if (wildmat (cp1, cp, NULLCHARP)) {
+					if ((cp2 = strrchr(toaddr1, '%')) != NULLCHAR) {
+						*cp1 = '\0';   /* Go and check any % directives */
+						*cp2 = '@';
+						rewind (fp);
+						continue;
+					} else {
+						fclose(fp);
+						return 1;
+					}
+				}
+			}
+		}
+	}
+	fclose (fp);
+	return 0;
+}
+
+/* Returns address of host connected to SMTP port */
+uint32
+getaddr (struct smtpsv * mp)
+{
+int sizesock;
+struct sockaddr_in fsock;
+	
+	sizesock = sizeof(fsock);
+	
+	if (getpeername(mp->s, (char *)&fsock, &sizesock) == 0 && sizesock !=0 && fsock.sin_family == AF_INET)
+		return fsock.sin_addr.s_addr;
+	else
+		return 0;
+}
+
+#ifdef HOLDMODS
+/* Scans a message about to be queued by SMTP for 'naughty words' */
+int
+scan_message (FILE *data, char *badbuf, char *badwords[])
+{
+int Holdit = 0;
+char buf[LINELEN];
+	rewind (data);
+	while (fgets (buf, sizeof (buf), data) != NULLCHAR) {
+		kwait (NULL);
+		Holdit = holdscan (buf, badbuf, badwords);
+		if (Holdit)
+			break;
+	}
+	return Holdit;
+}
+
+int
+load_badwords (char *badbuf, char *badwords[], int lnbadbuf)
+{
+FILE *fpp;
+int	theindex = 0;
+	if ((fpp = fopen (WordHoldFile, "r")) != NULLFILE) {
+		while (fgets (badbuf, lnbadbuf, fpp) != NULLCHAR) {
+			rip (badbuf);
+			if (strlen (badbuf) < 3)
+				continue;
+			(void) strlwr (badbuf);
+			badwords[theindex++] = strdup (badbuf);
+			if (theindex == 99)
+				break;
+		}
+		(void) fclose (fpp);
+	}
+	badwords[theindex] = NULLCHAR;
+	return (theindex);
+}
+#endif
