@@ -21,7 +21,7 @@
 #include "iface.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: tcpcmd.c,v 1.21 1997/09/07 00:31:16 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: tcpcmd.c,v 1.23 2001/05/08 12:26:46 brian Exp $";
 #endif
 
 #ifdef  TCPACCESS
@@ -309,7 +309,21 @@ void *p OPTIONAL;
 {
 register struct tcb *tcb;
 
-	tcb = (struct tcb *) htoi (argv[1]);
+   
+	if (strcmp (argv[1], "0") == 0) { /* If 'tcp kick 0' - kick everything */
+		for (tcb = Tcbs; tcb != NULLTCB; tcb = tcb->next) {
+			switch (tcb->state) {
+				case TCP_ESTABLISHED:
+				case TCP_FINWAIT1:
+				    kick_tcp (tcb);
+				default:
+				    continue;
+			}
+		}
+		return 0;
+	}
+  
+	tcb = (struct tcb *) htoi (argv[1]); /* Kick a single tcb */
 	if (kick_tcp (tcb) == -1) {
 		tputs (Notval);
 		return 1;
@@ -1071,7 +1085,7 @@ doiftcp (int argc, char *argv[], void *p)
 }
 
 
-int 
+static int 
 doiftcpblimit (int argc, char *argv[], void *p)
 {
 struct iface *ifp = p;
@@ -1080,7 +1094,7 @@ struct iface *ifp = p;
 }
 
 
-int 
+static int 
 doiftcpirtt (int argc, char *argv[], void *p)
 {
 struct iface *ifp = p;
@@ -1089,7 +1103,7 @@ struct iface *ifp = p;
 }
 
 
-int 
+static int 
 doiftcpmaxwait (int argc, char *argv[], void *p)
 {
 struct iface *ifp = p;
@@ -1098,7 +1112,7 @@ struct iface *ifp = p;
 }
 
 
-int 
+static int 
 doiftcpmss (int argc, char *argv[], void *p)
 {
 struct iface *ifp = p;
@@ -1107,7 +1121,7 @@ struct iface *ifp = p;
 }
 
 
-int 
+static int 
 doiftcpretries (int argc, char *argv[], void *p)
 {
 struct iface *ifp = p;
@@ -1116,7 +1130,7 @@ struct iface *ifp = p;
 }
 
 
-int 
+static int 
 doiftcptimertype (int argc, char *argv[], void *p)
 {
 struct iface *ifp = p;
@@ -1125,7 +1139,7 @@ struct iface *ifp = p;
 }
 
 
-int 
+static int 
 doiftcpwindow (int argc, char *argv[], void *p)
 {
 struct iface *ifp = p;
@@ -1134,7 +1148,7 @@ struct iface *ifp = p;
 }
 
 
-int 
+static int 
 doiftcpsyndata (int argc, char *argv[], void *p)
 {
 struct iface *ifp = p;
