@@ -15,7 +15,7 @@
 #include "icmp.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: tcpin.c,v 1.18 1997/05/24 13:01:20 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: tcpin.c,v 1.19 1997/09/07 00:31:16 root Exp $";
 #endif
 
 static void update (struct tcb * tcb, struct tcp * seg, int16 length);
@@ -93,7 +93,7 @@ int16 length;
 			return;
 		}
 #ifdef  TCPACCESS
-		if (tcp_check (TCPaccess, ip->source, seg.dest) != 0) {
+		if (tcp_check (TCPaccess, ip->source, seg.dest) > 0) {
 			free_p (bp);
 			reset (ip, &seg);
 			return;
