@@ -4,6 +4,7 @@
 
  
 #include <stdio.h>
+#include <string.h>
 #include "map.h"
 
 
@@ -18,10 +19,10 @@ unsigned char string[MAPLENGTH + 1];
 char const *format = "%s\n";
 char const *format2 = "%s\t%d\n";
 
-void
+int
 main (int argc, char *argv[])
 {
-int index = 1;
+int theindex = 1;
 char *tmp;
 unsigned char *cp;
 char buf[3];
@@ -42,8 +43,8 @@ int mode = PLAIN;
 		mode = HEADER;
 	}
 	if (argc == 4 && !strcmp (argv[1], "Features") && !strcmp (argv[2], "map:"))
-		index = 3;
-	tmp = argv[index];
+		theindex = 3;
+	tmp = argv[theindex];
 	cp = string;
 	while (*tmp)	{
 		buf[0] = *tmp++;
@@ -58,6 +59,7 @@ int mode = PLAIN;
 	CHECKFOR(ALLSERV);
 	CHECKFOR(ALLSESSIONS);
 	CHECKFOR(ALTERBID);
+	CHECKFOR(APRSD);
 	CHECKFOR(ARCNET);
 	CHECKFOR(ASKHOME);
 	CHECKFOR(ASY);
@@ -65,6 +67,7 @@ int mode = PLAIN;
 	CHECKFOR(AUTOROUTE);
 	CHECKFOR(AXBCSTR);
 	CHECKFOR(AXIP);
+	CHECKFOR(AXUDP);
 	CHECKFOR(AXUI);
 	CHECKFOR(BBSEXPORT);
 	CHECKFOR(BBSIMPORT);
@@ -127,6 +130,7 @@ int mode = PLAIN;
 	CHECKFOR(NR4TDISC);
 	CHECKFOR(NRS);
 	CHECKFOR(PACKET);
+	CHECKFOR(PATCURSES);
 	CHECKFOR(PC100);
 	CHECKFOR(PC_EC);
 	CHECKFOR(PI);
@@ -175,6 +179,7 @@ int mode = PLAIN;
 	CHECKFOR(STATS_TFC);
 	CHECKFOR(STATS_USE);
 	CHECKFOR(STRICT_CALL);
+	CHECKFOR(STRICT_AX25CALL);
 	CHECKFOR(STRICT_HTTPCALL);
 	CHECKFOR(TCPACCESS);
 	CHECKFOR(TCPGATE);
@@ -187,6 +192,7 @@ int mode = PLAIN;
 	CHECKFOR(TTYCALL);
 	CHECKFOR(TUTOR);
 	CHECKFOR(UDPACCESS);
+	CHECKFOR(UKIP);
 	CHECKFOR(UNIX_SOCKETS);
 	CHECKFOR(USEPOP3);
 	CHECKFOR(USERLOG);
@@ -198,8 +204,6 @@ int mode = PLAIN;
 	CHECKFOR(XMODEM);
 	CHECKFOR(XSERVER);
 
-	CHECKFOR(UNUSED1);
-
 	if (mode != PLAIN)	{
 		printf (format2, "MTHRESH", 16384);
 		printf (format2, "NROWS", 25);
@@ -208,4 +212,5 @@ int mode = PLAIN;
 		printf (format2, "NSESSIONS", 20);
 		printf (format2, "DEFNSOCK", 40);
 	}
+    return 0;
 }
