@@ -14,14 +14,16 @@
 #include "stats.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: ttylink.c,v 1.21 1997/07/31 00:44:20 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: ttylink.c,v 1.23 2001/05/06 16:32:58 brian Exp $";
 #endif
 
 #ifdef ALLSERV
 static int Sttylink = -1;	/* Protoype socket for service */
 int Attended = TRUE;            /* default to attended mode */
 static int Screening;           /* default to non-screened mode */
-
+#ifdef PATCURSES
+extern void clrchatline (struct session * sp);
+#endif
 static char Tnbanner[] = "Welcome to TTY-Link at %s - The system is %s.\n";
 static char defaultDeny[] = "Sorry, but the SYSOP is unable to join you at this time...";
 extern const char SysopBusy[];
@@ -75,7 +77,7 @@ time_t nowtime;
 		
 		if (!Attended)	{
 busy:			usprintf (s, SysopBusy);
-close:			(void) shutdown (s, 1);
+toclose:			(void) shutdown (s, 1);
 			close_s (s);
 		} else {
 			if (Screening && !CHAToneshotBypass)	{
@@ -113,7 +115,7 @@ close:			(void) shutdown (s, 1);
 				switch (ScreenedCall)	{
 					case 0:		/* denied */
 						usprintf (s, "%s\n", (DENYstr && *DENYstr) ? DENYstr : defaultDeny);
-						goto close;
+						goto toclose;
 					case -1:	/* unanswered */
 						ScreenedCall = 0;
 #ifdef XSERVER
@@ -172,6 +174,10 @@ int validaddr;
 	MiscUsers++;
 #endif
 	theindex = sp - Sessions;
+#ifdef PATCURSES
+	if (sp->split)	/* clear to paint chatline */
+		clrchatline(sp);
+#endif
 
 	/* Initialize a Telnet protocol descriptor */
 	memset ((char *)&tn, 0, sizeof (tn));
@@ -258,7 +264,7 @@ void *p;
 
 
 /* if unattended mode is set - restrict ax25, telnet and maybe other sessions */
-int
+static int
 doattended(argc,argv,p)
 int argc;
 char *argv[];
@@ -269,7 +275,7 @@ void *p OPTIONAL;
 
 
 /* if attended mode is set, do we screen the incoming calls? */
-int
+static int
 doscreening(argc,argv,p)
 int argc;
 char *argv[];
@@ -280,7 +286,7 @@ void *p OPTIONAL;
 
 
 /* if attended mode is set, do we screen the incoming calls? */
-int
+static int
 doretries(argc,argv,p)
 int argc;
 char *argv[];
@@ -291,7 +297,7 @@ void *p OPTIONAL;
 
 
 /* to accept the waiting incoming call */
-int
+static int
 doaccept(argc,argv,p)
 int argc OPTIONAL;
 char *argv[] OPTIONAL;
@@ -303,7 +309,7 @@ void *p OPTIONAL;
 
 
 /* to deny the waiting incoming call */
-int
+static int
 dodeny(argc,argv,p)
 int argc OPTIONAL;
 char *argv[] OPTIONAL;
@@ -314,7 +320,7 @@ void *p OPTIONAL;
 }
 
 
-int
+static int
 dodenystr(argc,argv,p)
 int argc;
 char *argv[];
@@ -333,7 +339,7 @@ void *p OPTIONAL;
 
 
 #ifdef SOUNDS
-int
+static int
 doscreensound(argc,argv,p)
 int argc;
 char *argv[];
@@ -343,7 +349,7 @@ void *p OPTIONAL;
 }
 
 
-int
+static int
 doconnectsound(argc,argv,p)
 int argc;
 char *argv[];
