@@ -8,8 +8,15 @@
 #include "udp.h"
 #include "icmp.h"
 
+#ifdef AXUDP
+#include "axudp.h"
+#endif
+#ifdef APRSD
+#include "aprs.h"
+#endif
+
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: udp.c,v 1.15 1997/09/07 00:31:16 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: udp.c,v 1.16 2001/05/06 16:32:58 brian Exp $";
 #endif
 
 static struct udp_cb *lookup_udp (struct socket *thesocket);
@@ -229,6 +236,31 @@ int16 length;
 		lsocket.address = ip->dest;
 
 	lsocket.port = udp.dest;
+
+#ifdef  APRSD
+
+    /* 27Apr2001, VE4KLM, Internal comms for new APRS Server */
+
+    if (aprsd_frame (&udp))
+    {
+        aprsd_torf (iface, bp, ip);
+        return;
+    }
+
+#endif
+
+#ifdef  AXUDP
+
+    /* 12Mar2001, VE4KLM, New AXUDP interface */
+
+	if (axudp_frame (&udp))
+	{
+		axudp_input (iface, bp, ip);
+		return;
+	}
+
+#endif
+
 	/* See if there's somebody around to read it */
 	if ((up = lookup_udp (&lsocket)) == NULLUDP
 #ifdef UDPACCESS
