@@ -10,7 +10,7 @@
 #include "trace.h"
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: udpdump.c,v 1.10 1996/09/04 01:34:13 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: udpdump.c,v 1.11 2000/05/09 16:48:29 brian Exp $";
 #endif
 
 void rwho_dump (FILE *fp,struct mbuf **bpp);
@@ -30,6 +30,10 @@ int16 csum;
 	if (bpp == NULLBUFP || *bpp == NULLBUF)
 		return;
 
+#ifdef CTRACE
+	if (use_ctrace)
+		traceprintf (fp, Agreen);
+#endif
 	traceprintf (fp, "UDP:");
 
 	/* Compute checksum */
@@ -43,6 +47,11 @@ int16 csum;
 	(void) ntohudp (&udp, bpp);
 
 	traceprintf (fp, " len %u", udp.length);
+#ifdef CTRACE
+	if (use_ctrace)
+		traceprintf (fp, " %s%u%s->%s%u%s", Abold, udp.source, Aboldoff, Abold, udp.dest, Aboldoff);
+	else
+#endif
 	traceprintf (fp, " %u->%u", udp.source, udp.dest);
 	if (udp.length > UDPHDR)
 		traceprintf (fp, " Data %u", udp.length - UDPHDR);
