@@ -14,7 +14,7 @@
 
 
 #if !defined(_lint)
-static char rcsid[] OPTIONAL = "$Id: version.c,v 1.26 1997/09/07 00:31:16 root Exp root $";
+static char rcsid[] OPTIONAL = "$Id: version.c,v 1.27 2000/05/09 16:48:29 brian Exp $";
 #endif
 
 #ifdef __ELF__
@@ -313,7 +313,10 @@ int k;
 	tputs("without compression");
 #endif
 #endif
-
+#ifdef UKIP
+	tputs("   'UKIP' enhancements ");
+	++k;
+#endif
 	tputs("\n");
 
 #endif /* MAILBOX */
@@ -557,6 +560,10 @@ int k;
     tputs("SM0RGV Forth\n");
 #endif
 
+#ifdef PATCURSES
+	tputs("Thomas Lucaw's color patches\n");
+#endif
+
 #endif
 
 	return 0;
